ghostty_vte_bindings_generated library

Classes

GhosttyAllocator
Custom memory allocator.
GhosttyAllocatorVtable
Function table for custom memory allocator operations.
GhosttyColorRgb
RGB color value.
GhosttyDeviceAttributes
Device attributes response data for all three DA levels.
GhosttyDeviceAttributesPrimary
Primary device attributes (DA1) response data.
GhosttyDeviceAttributesSecondary
Secondary device attributes (DA2) response data.
GhosttyDeviceAttributesTertiary
Tertiary device attributes (DA3) response data.
GhosttyFormatterImpl
GhosttyFormatterScreenExtra
Extra screen state to include in styled output.
GhosttyFormatterTerminalExtra
Extra terminal state to include in styled output.
GhosttyFormatterTerminalOptions
Options for creating a terminal formatter.
GhosttyGridRef
A resolved reference to a terminal cell position.
GhosttyKeyEncoderImpl
GhosttyKeyEventImpl
GhosttyMouseEncoderImpl
GhosttyMouseEncoderSize
Mouse encoder size and geometry context.
GhosttyMouseEventImpl
GhosttyMousePosition
Mouse position in surface-space pixels.
GhosttyOscCommandImpl
GhosttyOscParserImpl
GhosttyPoint
Tagged union for a point in the terminal grid.
GhosttyPointCoordinate
A coordinate in the terminal grid.
GhosttyPointValue
Point value union.
GhosttyRenderStateColors
Render-state color information.
GhosttyRenderStateImpl
GhosttyRenderStateRowCellsImpl
GhosttyRenderStateRowIteratorImpl
GhosttySgrAttribute
SGR attribute (tagged union).
GhosttySgrAttributeValue
SGR attribute value union.
GhosttySgrParserImpl
GhosttySgrUnknown
Unknown SGR attribute data.
GhosttySizeReportSize
Terminal size information for encoding size reports.
GhosttyString
A borrowed byte string (pointer + length).
GhosttyStyle
Terminal cell style.
GhosttyStyleColor
Style color (tagged union).
GhosttyStyleColorValue
Style color value union.
GhosttyTerminalImpl
GhosttyTerminalOptions
Terminal initialization options.
GhosttyTerminalScrollbar
Scrollbar state for the terminal viewport.
GhosttyTerminalScrollViewport
Tagged union for scroll viewport behavior.
GhosttyTerminalScrollViewportValue
Scroll viewport value.

Enums

GhosttyBuildInfo
Build info data types that can be queried.
GhosttyCellContentTag
Cell content tag.
GhosttyCellData
Cell data types.
GhosttyCellSemanticContent
Semantic content type of a cell.
GhosttyCellWide
Cell wide property.
GhosttyColorScheme
Color scheme reported in response to a CSI ? 996 n query.
GhosttyFocusEvent
Focus event types for focus reporting mode (mode 1004).
GhosttyFormatterFormat
Output format.
GhosttyKey
Physical key codes.
GhosttyKeyAction
Keyboard input event types.
GhosttyKeyEncoderOption
Key encoder option identifiers.
GhosttyModeReportState
DECRPM report state values.
GhosttyMouseAction
Mouse event action type.
GhosttyMouseButton
Mouse button identity.
GhosttyMouseEncoderOption
Mouse encoder option identifiers.
GhosttyMouseFormat
Mouse output format.
GhosttyMouseTrackingMode
Mouse tracking mode.
GhosttyOptimizeMode
Build optimization mode.
GhosttyOptionAsAlt
macOS option key behavior.
GhosttyOscCommandData
OSC command data types.
GhosttyOscCommandType
OSC command types.
GhosttyPointTag
Point reference tag.
GhosttyRenderStateCursorVisualStyle
Visual style of the cursor.
GhosttyRenderStateData
Queryable data kinds for ghostty_render_state_get().
GhosttyRenderStateDirty
Dirty state of a render state after update.
GhosttyRenderStateOption
Settable options for ghostty_render_state_set().
GhosttyRenderStateRowCellsData
Queryable data kinds for ghostty_render_state_row_cells_get().
GhosttyRenderStateRowData
Queryable data kinds for ghostty_render_state_row_get().
GhosttyRenderStateRowOption
Settable options for ghostty_render_state_row_set().
GhosttyResult
Result codes for libghostty-vt operations.
GhosttyRowData
Row data types.
GhosttyRowSemanticPrompt
Row semantic prompt state.
GhosttySgrAttributeTag
SGR attribute tags.
GhosttySgrUnderline
Underline style types.
GhosttySizeReportStyle
Size report style.
GhosttyStyleColorTag
Style color tags.
GhosttyTerminalData
Terminal data types.
GhosttyTerminalOption
Terminal option identifiers.
GhosttyTerminalScreen
Terminal screen identifier.
GhosttyTerminalScrollViewportTag
Scroll viewport behavior tag.

Constants

GHOSTTY_COLOR_NAMED_BLACK → const int
GHOSTTY_COLOR_NAMED_BLUE → const int
GHOSTTY_COLOR_NAMED_BRIGHT_BLACK → const int
GHOSTTY_COLOR_NAMED_BRIGHT_BLUE → const int
GHOSTTY_COLOR_NAMED_BRIGHT_CYAN → const int
GHOSTTY_COLOR_NAMED_BRIGHT_GREEN → const int
GHOSTTY_COLOR_NAMED_BRIGHT_MAGENTA → const int
GHOSTTY_COLOR_NAMED_BRIGHT_RED → const int
GHOSTTY_COLOR_NAMED_BRIGHT_WHITE → const int
GHOSTTY_COLOR_NAMED_BRIGHT_YELLOW → const int
GHOSTTY_COLOR_NAMED_CYAN → const int
GHOSTTY_COLOR_NAMED_GREEN → const int
GHOSTTY_COLOR_NAMED_MAGENTA → const int
GHOSTTY_COLOR_NAMED_RED → const int
GHOSTTY_COLOR_NAMED_WHITE → const int
GHOSTTY_COLOR_NAMED_YELLOW → const int
GHOSTTY_DA_CONFORMANCE_LEVEL_2 → const int
GHOSTTY_DA_CONFORMANCE_LEVEL_3 → const int
GHOSTTY_DA_CONFORMANCE_LEVEL_4 → const int
GHOSTTY_DA_CONFORMANCE_LEVEL_5 → const int
GHOSTTY_DA_CONFORMANCE_VT100 → const int
GHOSTTY_DA_CONFORMANCE_VT101 → const int
GHOSTTY_DA_CONFORMANCE_VT102 → const int
GHOSTTY_DA_CONFORMANCE_VT125 → const int
GHOSTTY_DA_CONFORMANCE_VT131 → const int
GHOSTTY_DA_CONFORMANCE_VT132 → const int
GHOSTTY_DA_CONFORMANCE_VT220 → const int
GHOSTTY_DA_CONFORMANCE_VT240 → const int
GHOSTTY_DA_CONFORMANCE_VT320 → const int
GHOSTTY_DA_CONFORMANCE_VT340 → const int
GHOSTTY_DA_CONFORMANCE_VT420 → const int
GHOSTTY_DA_CONFORMANCE_VT510 → const int
GHOSTTY_DA_CONFORMANCE_VT520 → const int
GHOSTTY_DA_CONFORMANCE_VT525 → const int
GHOSTTY_DA_DEVICE_TYPE_VT100 → const int
GHOSTTY_DA_DEVICE_TYPE_VT220 → const int
GHOSTTY_DA_DEVICE_TYPE_VT240 → const int
GHOSTTY_DA_DEVICE_TYPE_VT320 → const int
GHOSTTY_DA_DEVICE_TYPE_VT330 → const int
GHOSTTY_DA_DEVICE_TYPE_VT340 → const int
GHOSTTY_DA_DEVICE_TYPE_VT382 → const int
GHOSTTY_DA_DEVICE_TYPE_VT420 → const int
GHOSTTY_DA_DEVICE_TYPE_VT510 → const int
GHOSTTY_DA_DEVICE_TYPE_VT520 → const int
GHOSTTY_DA_DEVICE_TYPE_VT525 → const int
GHOSTTY_DA_FEATURE_ANSI_COLOR → const int
GHOSTTY_DA_FEATURE_ANSI_TEXT_LOCATOR → const int
GHOSTTY_DA_FEATURE_CLIPBOARD → const int
GHOSTTY_DA_FEATURE_COLUMNS_132 → const int
GHOSTTY_DA_FEATURE_HORIZONTAL_SCROLLING → const int
GHOSTTY_DA_FEATURE_LOCATOR → const int
GHOSTTY_DA_FEATURE_NATIONAL_REPLACEMENT → const int
GHOSTTY_DA_FEATURE_PRINTER → const int
GHOSTTY_DA_FEATURE_RECTANGULAR_EDITING → const int
GHOSTTY_DA_FEATURE_REGIS → const int
GHOSTTY_DA_FEATURE_SELECTIVE_ERASE → const int
GHOSTTY_DA_FEATURE_SIXEL → const int
GHOSTTY_DA_FEATURE_TECHNICAL_CHARACTERS → const int
GHOSTTY_DA_FEATURE_TERMINAL_STATE → const int
GHOSTTY_DA_FEATURE_USER_DEFINED_KEYS → const int
GHOSTTY_DA_FEATURE_WINDOWING → const int
GHOSTTY_KITTY_KEY_ALL → const int
GHOSTTY_KITTY_KEY_DISABLED → const int
GHOSTTY_KITTY_KEY_DISAMBIGUATE → const int
GHOSTTY_KITTY_KEY_REPORT_ALL → const int
GHOSTTY_KITTY_KEY_REPORT_ALTERNATES → const int
GHOSTTY_KITTY_KEY_REPORT_ASSOCIATED → const int
GHOSTTY_KITTY_KEY_REPORT_EVENTS → const int
GHOSTTY_MODS_ALT → const int
GHOSTTY_MODS_ALT_SIDE → const int
GHOSTTY_MODS_CAPS_LOCK → const int
GHOSTTY_MODS_CTRL → const int
GHOSTTY_MODS_CTRL_SIDE → const int
GHOSTTY_MODS_NUM_LOCK → const int
GHOSTTY_MODS_SHIFT → const int
GHOSTTY_MODS_SHIFT_SIDE → const int
GHOSTTY_MODS_SUPER → const int
GHOSTTY_MODS_SUPER_SIDE → const int

Functions

ghostty_alloc(Pointer<GhosttyAllocator> allocator, int len) Pointer<Uint8>
Allocate a buffer of len bytes.
ghostty_build_info(GhosttyBuildInfo data, Pointer<Void> out) GhosttyResult
ghostty_cell_get(DartGhosttyCell cell, GhosttyCellData data, Pointer<Void> out) GhosttyResult
ghostty_color_rgb_get(GhosttyColorRgb color, Pointer<Uint8> r, Pointer<Uint8> g, Pointer<Uint8> b) → void
Get the RGB color components.
ghostty_focus_encode(GhosttyFocusEvent event, Pointer<Char> buf, int buf_len, Pointer<Size> out_written) GhosttyResult
ghostty_formatter_format_alloc(GhosttyFormatter formatter, Pointer<GhosttyAllocator> allocator, Pointer<Pointer<Uint8>> out_ptr, Pointer<Size> out_len) GhosttyResult
ghostty_formatter_format_buf(GhosttyFormatter formatter, Pointer<Uint8> buf, int buf_len, Pointer<Size> out_written) GhosttyResult
ghostty_formatter_free(GhosttyFormatter formatter) → void
Free a formatter instance.
ghostty_formatter_terminal_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyFormatter> formatter, GhosttyTerminal terminal, GhosttyFormatterTerminalOptions options) GhosttyResult
ghostty_free(Pointer<GhosttyAllocator> allocator, Pointer<Uint8> ptr, int len) → void
Free memory that was allocated by a libghostty-vt function.
ghostty_grid_ref_cell(Pointer<GhosttyGridRef> ref, Pointer<GhosttyCell> out_cell) GhosttyResult
ghostty_grid_ref_graphemes(Pointer<GhosttyGridRef> ref, Pointer<Uint32> buf, int buf_len, Pointer<Size> out_len) GhosttyResult
ghostty_grid_ref_row(Pointer<GhosttyGridRef> ref, Pointer<GhosttyRow> out_row) GhosttyResult
ghostty_grid_ref_style(Pointer<GhosttyGridRef> ref, Pointer<GhosttyStyle> out_style) GhosttyResult
ghostty_key_encoder_encode(GhosttyKeyEncoder encoder, GhosttyKeyEvent event, Pointer<Char> out_buf, int out_buf_size, Pointer<Size> out_len) GhosttyResult
ghostty_key_encoder_free(GhosttyKeyEncoder encoder) → void
Free a key encoder instance.
ghostty_key_encoder_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyKeyEncoder> encoder) GhosttyResult
ghostty_key_encoder_setopt(GhosttyKeyEncoder encoder, GhosttyKeyEncoderOption option, Pointer<Void> value) → void
ghostty_key_encoder_setopt_from_terminal(GhosttyKeyEncoder encoder, GhosttyTerminal terminal) → void
Set encoder options from a terminal's current state.
ghostty_key_event_free(GhosttyKeyEvent event) → void
Free a key event instance.
ghostty_key_event_get_action(GhosttyKeyEvent event) GhosttyKeyAction
ghostty_key_event_get_composing(GhosttyKeyEvent event) bool
Get whether the key event is part of a composition sequence.
ghostty_key_event_get_consumed_mods(GhosttyKeyEvent event) int
Get the consumed modifiers bitmask.
ghostty_key_event_get_key(GhosttyKeyEvent event) GhosttyKey
ghostty_key_event_get_mods(GhosttyKeyEvent event) int
Get the modifier keys bitmask.
ghostty_key_event_get_unshifted_codepoint(GhosttyKeyEvent event) int
Get the unshifted Unicode codepoint.
ghostty_key_event_get_utf8(GhosttyKeyEvent event, Pointer<Size> len) Pointer<Char>
Get the UTF-8 text generated by the key event.
ghostty_key_event_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyKeyEvent> event) GhosttyResult
ghostty_key_event_set_action(GhosttyKeyEvent event, GhosttyKeyAction action) → void
ghostty_key_event_set_composing(GhosttyKeyEvent event, bool composing) → void
Set whether the key event is part of a composition sequence.
ghostty_key_event_set_consumed_mods(GhosttyKeyEvent event, int consumed_mods) → void
Set the consumed modifiers bitmask.
ghostty_key_event_set_key(GhosttyKeyEvent event, GhosttyKey key) → void
ghostty_key_event_set_mods(GhosttyKeyEvent event, int mods) → void
Set the modifier keys bitmask.
ghostty_key_event_set_unshifted_codepoint(GhosttyKeyEvent event, int codepoint) → void
Set the unshifted Unicode codepoint.
ghostty_key_event_set_utf8(GhosttyKeyEvent event, Pointer<Char> utf8, int len) → void
Set the UTF-8 text generated by the key for the current keyboard layout.
ghostty_mode_report_encode(DartGhosttyMode mode, GhosttyModeReportState state, Pointer<Char> buf, int buf_len, Pointer<Size> out_written) GhosttyResult
ghostty_mouse_encoder_encode(GhosttyMouseEncoder encoder, GhosttyMouseEvent event, Pointer<Char> out_buf, int out_buf_size, Pointer<Size> out_len) GhosttyResult
ghostty_mouse_encoder_free(GhosttyMouseEncoder encoder) → void
Free a mouse encoder instance.
ghostty_mouse_encoder_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyMouseEncoder> encoder) GhosttyResult
ghostty_mouse_encoder_reset(GhosttyMouseEncoder encoder) → void
Reset internal encoder state.
ghostty_mouse_encoder_setopt(GhosttyMouseEncoder encoder, GhosttyMouseEncoderOption option, Pointer<Void> value) → void
ghostty_mouse_encoder_setopt_from_terminal(GhosttyMouseEncoder encoder, GhosttyTerminal terminal) → void
Set encoder options from a terminal's current state.
ghostty_mouse_event_clear_button(GhosttyMouseEvent event) → void
Clear the event button.
ghostty_mouse_event_free(GhosttyMouseEvent event) → void
Free a mouse event instance.
ghostty_mouse_event_get_action(GhosttyMouseEvent event) GhosttyMouseAction
ghostty_mouse_event_get_button(GhosttyMouseEvent event, Pointer<UnsignedInt> out_button) bool
Get the event button.
ghostty_mouse_event_get_mods(GhosttyMouseEvent event) int
Get keyboard modifiers held during the event.
ghostty_mouse_event_get_position(GhosttyMouseEvent event) GhosttyMousePosition
Get the event position in surface-space pixels.
ghostty_mouse_event_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyMouseEvent> event) GhosttyResult
ghostty_mouse_event_set_action(GhosttyMouseEvent event, GhosttyMouseAction action) → void
ghostty_mouse_event_set_button(GhosttyMouseEvent event, GhosttyMouseButton button) → void
ghostty_mouse_event_set_mods(GhosttyMouseEvent event, int mods) → void
Set keyboard modifiers held during the event.
ghostty_mouse_event_set_position(GhosttyMouseEvent event, GhosttyMousePosition position) → void
Set the event position in surface-space pixels.
ghostty_osc_command_data(GhosttyOscCommand command, GhosttyOscCommandData data, Pointer<Void> out) bool
ghostty_osc_command_type(GhosttyOscCommand command) GhosttyOscCommandType
ghostty_osc_end(GhosttyOscParser parser, int terminator) GhosttyOscCommand
Finalize OSC parsing and retrieve the parsed command.
ghostty_osc_free(GhosttyOscParser parser) → void
Free an OSC parser instance.
ghostty_osc_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyOscParser> parser) GhosttyResult
ghostty_osc_next(GhosttyOscParser parser, int byte) → void
Parse the next byte in an OSC sequence.
ghostty_osc_reset(GhosttyOscParser parser) → void
Reset an OSC parser instance to its initial state.
ghostty_paste_encode(Pointer<Char> data, int data_len, bool bracketed, Pointer<Char> buf, int buf_len, Pointer<Size> out_written) GhosttyResult
ghostty_paste_is_safe(Pointer<Char> data, int len) bool
Check if paste data is safe to paste into the terminal.
ghostty_render_state_colors_get(GhosttyRenderState state, Pointer<GhosttyRenderStateColors> out_colors) GhosttyResult
ghostty_render_state_free(GhosttyRenderState state) → void
Free a render state instance.
ghostty_render_state_get(GhosttyRenderState state, GhosttyRenderStateData data, Pointer<Void> out) GhosttyResult
ghostty_render_state_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyRenderState> state) GhosttyResult
ghostty_render_state_row_cells_free(GhosttyRenderStateRowCells cells) → void
Free a row cells instance.
ghostty_render_state_row_cells_get(GhosttyRenderStateRowCells cells, GhosttyRenderStateRowCellsData data, Pointer<Void> out) GhosttyResult
ghostty_render_state_row_cells_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyRenderStateRowCells> out_cells) GhosttyResult
ghostty_render_state_row_cells_next(GhosttyRenderStateRowCells cells) bool
Move a render-state row cells iterator to the next cell.
ghostty_render_state_row_cells_select(GhosttyRenderStateRowCells cells, int x) GhosttyResult
ghostty_render_state_row_get(GhosttyRenderStateRowIterator iterator, GhosttyRenderStateRowData data, Pointer<Void> out) GhosttyResult
ghostty_render_state_row_iterator_free(GhosttyRenderStateRowIterator iterator) → void
Free a render-state row iterator.
ghostty_render_state_row_iterator_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyRenderStateRowIterator> out_iterator) GhosttyResult
ghostty_render_state_row_iterator_next(GhosttyRenderStateRowIterator iterator) bool
Move a render-state row iterator to the next row.
ghostty_render_state_row_set(GhosttyRenderStateRowIterator iterator, GhosttyRenderStateRowOption option, Pointer<Void> value) GhosttyResult
ghostty_render_state_set(GhosttyRenderState state, GhosttyRenderStateOption option, Pointer<Void> value) GhosttyResult
ghostty_render_state_update(GhosttyRenderState state, GhosttyTerminal terminal) GhosttyResult
ghostty_row_get(DartGhosttyRow row, GhosttyRowData data, Pointer<Void> out) GhosttyResult
ghostty_sgr_attribute_tag(GhosttySgrAttribute attr) GhosttySgrAttributeTag
ghostty_sgr_attribute_value(Pointer<GhosttySgrAttribute> attr) Pointer<GhosttySgrAttributeValue>
Get the value from an SGR attribute.
ghostty_sgr_free(GhosttySgrParser parser) → void
Free an SGR parser instance.
ghostty_sgr_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttySgrParser> parser) GhosttyResult
ghostty_sgr_next(GhosttySgrParser parser, Pointer<GhosttySgrAttribute> attr) bool
Get the next SGR attribute.
ghostty_sgr_reset(GhosttySgrParser parser) → void
Reset an SGR parser instance to the beginning of the parameter list.
ghostty_sgr_set_params(GhosttySgrParser parser, Pointer<Uint16> params, Pointer<Char> separators, int len) GhosttyResult
ghostty_sgr_unknown_full(GhosttySgrUnknown unknown, Pointer<Pointer<Uint16>> ptr) int
Get the full parameter list from an unknown SGR attribute.
ghostty_sgr_unknown_partial(GhosttySgrUnknown unknown, Pointer<Pointer<Uint16>> ptr) int
Get the partial parameter list from an unknown SGR attribute.
ghostty_size_report_encode(GhosttySizeReportStyle style, GhosttySizeReportSize size, Pointer<Char> buf, int buf_len, Pointer<Size> out_written) GhosttyResult
ghostty_style_default(Pointer<GhosttyStyle> style) → void
Get the default style.
ghostty_style_is_default(Pointer<GhosttyStyle> style) bool
Check if a style is the default style.
ghostty_terminal_free(GhosttyTerminal terminal) → void
Free a terminal instance.
ghostty_terminal_get(GhosttyTerminal terminal, GhosttyTerminalData data, Pointer<Void> out) GhosttyResult
ghostty_terminal_grid_ref(GhosttyTerminal terminal, GhosttyPoint point, Pointer<GhosttyGridRef> out_ref) GhosttyResult
ghostty_terminal_mode_get(GhosttyTerminal terminal, DartGhosttyMode mode, Pointer<Bool> out_value) GhosttyResult
ghostty_terminal_mode_set(GhosttyTerminal terminal, DartGhosttyMode mode, bool value) GhosttyResult
ghostty_terminal_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyTerminal> terminal, GhosttyTerminalOptions options) GhosttyResult
ghostty_terminal_reset(GhosttyTerminal terminal) → void
Perform a full reset of the terminal (RIS).
ghostty_terminal_resize(GhosttyTerminal terminal, int cols, int rows, int cell_width_px, int cell_height_px) GhosttyResult
ghostty_terminal_scroll_viewport(GhosttyTerminal terminal, GhosttyTerminalScrollViewport behavior) → void
Scroll the terminal viewport.
ghostty_terminal_set(GhosttyTerminal terminal, GhosttyTerminalOption option, Pointer<Void> value) GhosttyResult
ghostty_terminal_vt_write(GhosttyTerminal terminal, Pointer<Uint8> data, int len) → void
Write VT-encoded data to the terminal for processing.

Typedefs

DartGhosttyCell = int
DartGhosttyColorPaletteIndex = int
DartGhosttyKittyKeyFlags = int
DartGhosttyMode = int
DartGhosttyMods = int
DartGhosttyRow = int
DartGhosttyStyleId = int
DartGhosttyTerminalBellFnFunction = void Function(GhosttyTerminal terminal, Pointer<Void> userdata)
DartGhosttyTerminalColorSchemeFnFunction = bool Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<UnsignedInt> out_scheme)
DartGhosttyTerminalDeviceAttributesFnFunction = bool Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<GhosttyDeviceAttributes> out_attrs)
DartGhosttyTerminalSizeFnFunction = bool Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<GhosttySizeReportSize> out_size)
DartGhosttyTerminalTitleChangedFnFunction = void Function(GhosttyTerminal terminal, Pointer<Void> userdata)
DartGhosttyTerminalWritePtyFnFunction = void Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<Uint8> data, int len)
GhosttyCell = Uint64
Opaque cell value.
GhosttyColorPaletteIndex = Uint8
Palette color index (0-255).
GhosttyFormatter = Pointer<GhosttyFormatterImpl>
Opaque handle to a formatter instance.
GhosttyKeyEncoder = Pointer<GhosttyKeyEncoderImpl>
Opaque handle to a key encoder instance.
GhosttyKeyEvent = Pointer<GhosttyKeyEventImpl>
Opaque handle to a key event.
GhosttyKittyKeyFlags = Uint8
Kitty keyboard protocol flags.
GhosttyMode = Uint16
A packed 16-bit terminal mode.
GhosttyMods = Uint16
Keyboard modifier keys bitmask.
GhosttyMouseEncoder = Pointer<GhosttyMouseEncoderImpl>
Opaque handle to a mouse encoder instance.
GhosttyMouseEvent = Pointer<GhosttyMouseEventImpl>
Opaque handle to a mouse event.
GhosttyOscCommand = Pointer<GhosttyOscCommandImpl>
Opaque handle to a single OSC command.
GhosttyOscParser = Pointer<GhosttyOscParserImpl>
Opaque handle to an OSC parser instance.
GhosttyRenderState = Pointer<GhosttyRenderStateImpl>
Opaque handle to a render state instance.
GhosttyRenderStateRowCells = Pointer<GhosttyRenderStateRowCellsImpl>
Opaque handle to render-state row cells.
GhosttyRenderStateRowIterator = Pointer<GhosttyRenderStateRowIteratorImpl>
Opaque handle to a render-state row iterator.
GhosttyRow = Uint64
Opaque row value.
GhosttySgrParser = Pointer<GhosttySgrParserImpl>
Opaque handle to an SGR parser instance.
GhosttyStyleId = Uint16
Style identifier type.
GhosttyTerminal = Pointer<GhosttyTerminalImpl>
Opaque handle to a terminal instance.
GhosttyTerminalBellFn = Pointer<NativeFunction<GhosttyTerminalBellFnFunction>>
Callback function type for bell.
GhosttyTerminalBellFnFunction = Void Function(GhosttyTerminal terminal, Pointer<Void> userdata)
GhosttyTerminalColorSchemeFn = Pointer<NativeFunction<GhosttyTerminalColorSchemeFnFunction>>
Callback function type for color scheme queries (CSI ? 996 n).
GhosttyTerminalColorSchemeFnFunction = Bool Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<UnsignedInt> out_scheme)
GhosttyTerminalDeviceAttributesFn = Pointer<NativeFunction<GhosttyTerminalDeviceAttributesFnFunction>>
Callback function type for device attributes queries (DA1/DA2/DA3).
GhosttyTerminalDeviceAttributesFnFunction = Bool Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<GhosttyDeviceAttributes> out_attrs)
GhosttyTerminalEnquiryFn = Pointer<NativeFunction<GhosttyTerminalEnquiryFnFunction>>
Callback function type for enquiry (ENQ, 0x05).
GhosttyTerminalEnquiryFnFunction = GhosttyString Function(GhosttyTerminal terminal, Pointer<Void> userdata)
GhosttyTerminalSizeFn = Pointer<NativeFunction<GhosttyTerminalSizeFnFunction>>
Callback function type for size queries (XTWINOPS).
GhosttyTerminalSizeFnFunction = Bool Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<GhosttySizeReportSize> out_size)
GhosttyTerminalTitleChangedFn = Pointer<NativeFunction<GhosttyTerminalTitleChangedFnFunction>>
Callback function type for title_changed.
GhosttyTerminalTitleChangedFnFunction = Void Function(GhosttyTerminal terminal, Pointer<Void> userdata)
GhosttyTerminalWritePtyFn = Pointer<NativeFunction<GhosttyTerminalWritePtyFnFunction>>
Callback function type for write_pty.
GhosttyTerminalWritePtyFnFunction = Void Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<Uint8> data, Size len)
GhosttyTerminalXtversionFn = Pointer<NativeFunction<GhosttyTerminalXtversionFnFunction>>
Callback function type for XTVERSION.
GhosttyTerminalXtversionFnFunction = GhosttyString Function(GhosttyTerminal terminal, Pointer<Void> userdata)