vtable property
Pointer to the allocator's vtable containing function pointers for memory operations (alloc, resize, remap, free).
Implementation
external ffi.Pointer<GhosttyAllocatorVtable> vtable;
Pointer to the allocator's vtable containing function pointers for memory operations (alloc, resize, remap, free).
external ffi.Pointer<GhosttyAllocatorVtable> vtable;