free property

Pointer<NativeFunction<Void Function(Pointer<Void> ctx, Pointer<Void> memory, Size memory_len, Uint8 alignment, UintPtr ret_addr)>> free
getter/setter pair

Free and invalidate a region of memory.

memory_len must equal the length requested from the most recent successful call to alloc, resize, or remap. alignment must equal the same value that was passed as the alignment parameter to the original alloc call.

@param ctx The allocator context @param memory Pointer to the memory block to free @param memory_len Size of the memory block @param alignment Alignment (must match original allocation) @param ret_addr First return address of the allocation call stack (0 if not provided)

Implementation

external ffi.Pointer<
  ffi.NativeFunction<
    ffi.Void Function(
      ffi.Pointer<ffi.Void> ctx,
      ffi.Pointer<ffi.Void> memory,
      ffi.Size memory_len,
      ffi.Uint8 alignment,
      ffi.UintPtr ret_addr,
    )
  >
>
free;