GhosttyBuildInfo enum
Build info data types that can be queried.
Each variant documents the expected output pointer type.
Values
- GHOSTTY_BUILD_INFO_INVALID → const GhosttyBuildInfo
-
Invalid data type. Never results in any data extraction.
const GhosttyBuildInfo(0) - GHOSTTY_BUILD_INFO_SIMD → const GhosttyBuildInfo
-
Whether SIMD-accelerated code paths are enabled.
Output type: bool *
const GhosttyBuildInfo(1) - GHOSTTY_BUILD_INFO_KITTY_GRAPHICS → const GhosttyBuildInfo
-
Whether Kitty graphics protocol support is available.
Output type: bool *
const GhosttyBuildInfo(2) - GHOSTTY_BUILD_INFO_TMUX_CONTROL_MODE → const GhosttyBuildInfo
-
Whether tmux control mode support is available.
Output type: bool *
const GhosttyBuildInfo(3) - GHOSTTY_BUILD_INFO_OPTIMIZE → const GhosttyBuildInfo
-
The optimization mode the library was built with.
Output type: GhosttyOptimizeMode *
const GhosttyBuildInfo(4) - GHOSTTY_BUILD_INFO_VERSION_STRING → const GhosttyBuildInfo
-
The full version string (e.g. "1.2.3" or "1.2.3-dev+abcdef").
Output type: GhosttyString *
const GhosttyBuildInfo(5) - GHOSTTY_BUILD_INFO_VERSION_MAJOR → const GhosttyBuildInfo
-
The major version number.
Output type: size_t *
const GhosttyBuildInfo(6) - GHOSTTY_BUILD_INFO_VERSION_MINOR → const GhosttyBuildInfo
-
The minor version number.
Output type: size_t *
const GhosttyBuildInfo(7) - GHOSTTY_BUILD_INFO_VERSION_PATCH → const GhosttyBuildInfo
-
The patch version number.
Output type: size_t *
const GhosttyBuildInfo(8) - GHOSTTY_BUILD_INFO_VERSION_BUILD → const GhosttyBuildInfo
-
The build metadata string (e.g. commit hash). Has zero length if no build metadata is present.
Output type: GhosttyString *
const GhosttyBuildInfo(9)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → GhosttyBuildInfo
Constants
-
values
→ const List<
GhosttyBuildInfo> - A constant List of the values in this enum, in order of their declaration.