GhosttyCellData enum

Cell data types.

These values specify what type of data to extract from a cell using ghostty_cell_get.

@ingroup screen

Inheritance
Available extensions

Values

GHOSTTY_CELL_DATA_INVALID → const GhosttyCellData

Invalid data type. Never results in any data extraction.

const GhosttyCellData(0)
GHOSTTY_CELL_DATA_CODEPOINT → const GhosttyCellData

The codepoint of the cell (0 if empty or bg-color-only).

Output type: uint32_t *

const GhosttyCellData(1)
GHOSTTY_CELL_DATA_CONTENT_TAG → const GhosttyCellData

The content tag describing what kind of content is in the cell.

Output type: GhosttyCellContentTag *

const GhosttyCellData(2)
GHOSTTY_CELL_DATA_WIDE → const GhosttyCellData

The wide property of the cell.

Output type: GhosttyCellWide *

const GhosttyCellData(3)
GHOSTTY_CELL_DATA_HAS_TEXT → const GhosttyCellData

Whether the cell has text to render.

Output type: bool *

const GhosttyCellData(4)
GHOSTTY_CELL_DATA_HAS_STYLING → const GhosttyCellData

Whether the cell has non-default styling.

Output type: bool *

const GhosttyCellData(5)
GHOSTTY_CELL_DATA_STYLE_ID → const GhosttyCellData

The style ID for the cell (for use with style lookups).

Output type: uint16_t *

const GhosttyCellData(6)

Whether the cell has a hyperlink.

Output type: bool *

const GhosttyCellData(7)
GHOSTTY_CELL_DATA_PROTECTED → const GhosttyCellData

Whether the cell is protected.

Output type: bool *

const GhosttyCellData(8)
GHOSTTY_CELL_DATA_SEMANTIC_CONTENT → const GhosttyCellData

The semantic content type of the cell (from OSC 133).

Output type: GhosttyCellSemanticContent *

const GhosttyCellData(9)
GHOSTTY_CELL_DATA_COLOR_PALETTE → const GhosttyCellData

The palette index for the cell's background color. Only valid when content_tag is GHOSTTY_CELL_CONTENT_BG_COLOR_PALETTE.

Output type: GhosttyColorPaletteIndex *

const GhosttyCellData(10)
GHOSTTY_CELL_DATA_COLOR_RGB → const GhosttyCellData

The RGB value for the cell's background color. Only valid when content_tag is GHOSTTY_CELL_CONTENT_BG_COLOR_RGB.

Output type: GhosttyColorRgb *

const GhosttyCellData(11)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyCellData

Constants

values → const List<GhosttyCellData>
A constant List of the values in this enum, in order of their declaration.