GhosttyCellSemanticContent enum

Semantic content type of a cell.

Set by semantic prompt sequences (OSC 133) to distinguish between command output, user input, and shell prompt text.

@ingroup screen

Inheritance
Available extensions

Values

GHOSTTY_CELL_SEMANTIC_OUTPUT → const GhosttyCellSemanticContent

Regular output content, such as command output.

const GhosttyCellSemanticContent(0)
GHOSTTY_CELL_SEMANTIC_INPUT → const GhosttyCellSemanticContent

Content that is part of user input.

const GhosttyCellSemanticContent(1)
GHOSTTY_CELL_SEMANTIC_PROMPT → const GhosttyCellSemanticContent

Content that is part of a shell prompt.

const GhosttyCellSemanticContent(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyCellSemanticContent

Constants

values → const List<GhosttyCellSemanticContent>
A constant List of the values in this enum, in order of their declaration.