GhosttyCellWide enum

Cell wide property.

Describes the width behavior of a cell.

@ingroup screen

Inheritance
Available extensions

Values

GHOSTTY_CELL_WIDE_NARROW → const GhosttyCellWide

Not a wide character, cell width 1.

const GhosttyCellWide(0)
GHOSTTY_CELL_WIDE_WIDE → const GhosttyCellWide

Wide character, cell width 2.

const GhosttyCellWide(1)
GHOSTTY_CELL_WIDE_SPACER_TAIL → const GhosttyCellWide

Spacer after wide character. Do not render.

const GhosttyCellWide(2)
GHOSTTY_CELL_WIDE_SPACER_HEAD → const GhosttyCellWide

Spacer at end of soft-wrapped line for a wide character.

const GhosttyCellWide(3)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyCellWide

Constants

values → const List<GhosttyCellWide>
A constant List of the values in this enum, in order of their declaration.