GhosttyColorPaletteMask class final

A 256-bit mask of palette indices.

Index i is set iff (bits[i >> 6] >> (i & 63)) & 1 is 1. The mask is typically initialized to zero and then populated with GHOSTTY_COLOR_PALETTE_MASK_SET().

@code{.c} GhosttyColorPaletteMask mask = {0}; GHOSTTY_COLOR_PALETTE_MASK_SET(&mask, 20); if (GHOSTTY_COLOR_PALETTE_MASK_IS_SET(&mask, 20)) { // Index 20 will be preserved. } @endcode

@ingroup color

Inheritance
Implemented types
Available extensions

Constructors

GhosttyColorPaletteMask()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bits Array<Uint64>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited