GhosttyColorRgb class final

RGB color value.

@ingroup sgr

Inheritance
Implemented types
Available extensions

Constructors

GhosttyColorRgb()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
b int
< Blue component (0-255)
getter/setter pair
g int
< Green component (0-255)
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
r int
< Red component (0-255)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited