GhosttyColorScheme enum

Color scheme reported in response to a CSI ? 996 n query.

@ingroup terminal

Inheritance
Available extensions

Values

GHOSTTY_COLOR_SCHEME_LIGHT → const GhosttyColorScheme
const GhosttyColorScheme(0)
GHOSTTY_COLOR_SCHEME_DARK → const GhosttyColorScheme
const GhosttyColorScheme(1)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyColorScheme

Constants

values → const List<GhosttyColorScheme>
A constant List of the values in this enum, in order of their declaration.