GhosttyColorX11Entry class final

An entry in Ghostty's X11 color name table.

@ingroup color

Inheritance
Implemented types
Available extensions

Constructors

GhosttyColorX11Entry()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
color GhosttyColorRgb
The RGB value of the color.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name Pointer<Char>
Null-terminated color name. NULL marks the end of the table.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited