GhosttyDeviceAttributesSecondary class final
Secondary device attributes (DA2) response data.
Returned as part of GhosttyDeviceAttributes in response to a CSI > c query. Response format: CSI > Pp ; Pv ; Pc c
@ingroup terminal
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - device_type ↔ int
-
Terminal type identifier (Pp). E.g. 1 for VT220.
getter/setter pair
- firmware_version ↔ int
-
Firmware/patch version number (Pv).
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- rom_cartridge ↔ int
-
ROM cartridge registration number (Pc). Always 0 for emulators.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited