GhosttyFormatterFormat enum

Output format.

@ingroup formatter

Inheritance
Available extensions

Values

GHOSTTY_FORMATTER_FORMAT_PLAIN → const GhosttyFormatterFormat

Plain text (no escape sequences).

const GhosttyFormatterFormat(0)
GHOSTTY_FORMATTER_FORMAT_VT → const GhosttyFormatterFormat

VT sequences preserving colors, styles, URLs, etc.

const GhosttyFormatterFormat(1)
GHOSTTY_FORMATTER_FORMAT_HTML → const GhosttyFormatterFormat

HTML with inline styles.

const GhosttyFormatterFormat(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyFormatterFormat

Constants

values → const List<GhosttyFormatterFormat>
A constant List of the values in this enum, in order of their declaration.