GhosttyFormatterScreenExtra class final
Extra screen state to include in styled output.
@ingroup formatter
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - charsets ↔ bool
-
Emit character set designations and invocations.
getter/setter pair
- cursor ↔ bool
-
Emit cursor position using CUP (CSI H).
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hyperlink ↔ bool
-
Emit current hyperlink state using OSC 8 sequences.
getter/setter pair
- kitty_keyboard ↔ bool
-
Emit Kitty keyboard protocol state using CSI > u and CSI = sequences.
getter/setter pair
- protection ↔ bool
-
Emit character protection mode using DECSCA.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size ↔ int
-
Size of this struct in bytes. Must be set to sizeof(GhosttyFormatterScreenExtra).
getter/setter pair
- style ↔ bool
-
Emit current SGR style state based on the cursor's active style_id.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited