GhosttyFormatterTerminalExtra class final

Extra terminal state to include in styled output.

@ingroup formatter

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
keyboard bool
Emit keyboard modes such as ModifyOtherKeys.
getter/setter pair
modes bool
Emit terminal modes that differ from their defaults using CSI h/l.
getter/setter pair
palette bool
Emit the palette using OSC 4 sequences.
getter/setter pair
pwd bool
Emit the present working directory using OSC 7.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screen GhosttyFormatterScreenExtra
Screen-level extras.
getter/setter pair
scrolling_region bool
Emit scrolling region state using DECSTBM and DECSLRM sequences.
getter/setter pair
size int
Size of this struct in bytes. Must be set to sizeof(GhosttyFormatterTerminalExtra).
getter/setter pair
tabstops bool
Emit tabstop positions by clearing all tabs and setting each one.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited