GhosttyKey enum

Physical key codes.

The set of key codes that Ghostty is aware of. These represent physical keys on the keyboard and are layout-independent. For example, the "a" key on a US keyboard is the same as the "ф" key on a Russian keyboard, but both will report the same key_a value.

Layout-dependent strings are provided separately as UTF-8 text and are produced by the platform. These values are based on the W3C UI Events KeyboardEvent code standard. See: https://www.w3.org/TR/uievents-code

@ingroup key

Inheritance
Available extensions

Values

GHOSTTY_KEY_UNIDENTIFIED → const GhosttyKey
const GhosttyKey(0)
GHOSTTY_KEY_BACKQUOTE → const GhosttyKey

Writing System Keys (W3C  3.1.1)

const GhosttyKey(1)
GHOSTTY_KEY_BACKSLASH → const GhosttyKey
const GhosttyKey(2)
GHOSTTY_KEY_BRACKET_LEFT → const GhosttyKey
const GhosttyKey(3)
GHOSTTY_KEY_BRACKET_RIGHT → const GhosttyKey
const GhosttyKey(4)
GHOSTTY_KEY_COMMA → const GhosttyKey
const GhosttyKey(5)
GHOSTTY_KEY_DIGIT_0 → const GhosttyKey
const GhosttyKey(6)
GHOSTTY_KEY_DIGIT_1 → const GhosttyKey
const GhosttyKey(7)
GHOSTTY_KEY_DIGIT_2 → const GhosttyKey
const GhosttyKey(8)
GHOSTTY_KEY_DIGIT_3 → const GhosttyKey
const GhosttyKey(9)
GHOSTTY_KEY_DIGIT_4 → const GhosttyKey
const GhosttyKey(10)
GHOSTTY_KEY_DIGIT_5 → const GhosttyKey
const GhosttyKey(11)
GHOSTTY_KEY_DIGIT_6 → const GhosttyKey
const GhosttyKey(12)
GHOSTTY_KEY_DIGIT_7 → const GhosttyKey
const GhosttyKey(13)
GHOSTTY_KEY_DIGIT_8 → const GhosttyKey
const GhosttyKey(14)
GHOSTTY_KEY_DIGIT_9 → const GhosttyKey
const GhosttyKey(15)
GHOSTTY_KEY_EQUAL → const GhosttyKey
const GhosttyKey(16)
GHOSTTY_KEY_INTL_BACKSLASH → const GhosttyKey
const GhosttyKey(17)
GHOSTTY_KEY_INTL_RO → const GhosttyKey
const GhosttyKey(18)
GHOSTTY_KEY_INTL_YEN → const GhosttyKey
const GhosttyKey(19)
GHOSTTY_KEY_A → const GhosttyKey
const GhosttyKey(20)
GHOSTTY_KEY_B → const GhosttyKey
const GhosttyKey(21)
GHOSTTY_KEY_C → const GhosttyKey
const GhosttyKey(22)
GHOSTTY_KEY_D → const GhosttyKey
const GhosttyKey(23)
GHOSTTY_KEY_E → const GhosttyKey
const GhosttyKey(24)
GHOSTTY_KEY_F → const GhosttyKey
const GhosttyKey(25)
GHOSTTY_KEY_G → const GhosttyKey
const GhosttyKey(26)
GHOSTTY_KEY_H → const GhosttyKey
const GhosttyKey(27)
GHOSTTY_KEY_I → const GhosttyKey
const GhosttyKey(28)
GHOSTTY_KEY_J → const GhosttyKey
const GhosttyKey(29)
GHOSTTY_KEY_K → const GhosttyKey
const GhosttyKey(30)
GHOSTTY_KEY_L → const GhosttyKey
const GhosttyKey(31)
GHOSTTY_KEY_M → const GhosttyKey
const GhosttyKey(32)
GHOSTTY_KEY_N → const GhosttyKey
const GhosttyKey(33)
GHOSTTY_KEY_O → const GhosttyKey
const GhosttyKey(34)
GHOSTTY_KEY_P → const GhosttyKey
const GhosttyKey(35)
GHOSTTY_KEY_Q → const GhosttyKey
const GhosttyKey(36)
GHOSTTY_KEY_R → const GhosttyKey
const GhosttyKey(37)
GHOSTTY_KEY_S → const GhosttyKey
const GhosttyKey(38)
GHOSTTY_KEY_T → const GhosttyKey
const GhosttyKey(39)
GHOSTTY_KEY_U → const GhosttyKey
const GhosttyKey(40)
GHOSTTY_KEY_V → const GhosttyKey
const GhosttyKey(41)
GHOSTTY_KEY_W → const GhosttyKey
const GhosttyKey(42)
GHOSTTY_KEY_X → const GhosttyKey
const GhosttyKey(43)
GHOSTTY_KEY_Y → const GhosttyKey
const GhosttyKey(44)
GHOSTTY_KEY_Z → const GhosttyKey
const GhosttyKey(45)
GHOSTTY_KEY_MINUS → const GhosttyKey
const GhosttyKey(46)
GHOSTTY_KEY_PERIOD → const GhosttyKey
const GhosttyKey(47)
GHOSTTY_KEY_QUOTE → const GhosttyKey
const GhosttyKey(48)
GHOSTTY_KEY_SEMICOLON → const GhosttyKey
const GhosttyKey(49)
GHOSTTY_KEY_SLASH → const GhosttyKey
const GhosttyKey(50)
GHOSTTY_KEY_ALT_LEFT → const GhosttyKey

Functional Keys (W3C  3.1.2)

const GhosttyKey(51)
GHOSTTY_KEY_ALT_RIGHT → const GhosttyKey
const GhosttyKey(52)
GHOSTTY_KEY_BACKSPACE → const GhosttyKey
const GhosttyKey(53)
GHOSTTY_KEY_CAPS_LOCK → const GhosttyKey
const GhosttyKey(54)
GHOSTTY_KEY_CONTEXT_MENU → const GhosttyKey
const GhosttyKey(55)
GHOSTTY_KEY_CONTROL_LEFT → const GhosttyKey
const GhosttyKey(56)
GHOSTTY_KEY_CONTROL_RIGHT → const GhosttyKey
const GhosttyKey(57)
GHOSTTY_KEY_ENTER → const GhosttyKey
const GhosttyKey(58)
GHOSTTY_KEY_META_LEFT → const GhosttyKey
const GhosttyKey(59)
GHOSTTY_KEY_META_RIGHT → const GhosttyKey
const GhosttyKey(60)
GHOSTTY_KEY_SHIFT_LEFT → const GhosttyKey
const GhosttyKey(61)
GHOSTTY_KEY_SHIFT_RIGHT → const GhosttyKey
const GhosttyKey(62)
GHOSTTY_KEY_SPACE → const GhosttyKey
const GhosttyKey(63)
GHOSTTY_KEY_TAB → const GhosttyKey
const GhosttyKey(64)
GHOSTTY_KEY_CONVERT → const GhosttyKey
const GhosttyKey(65)
GHOSTTY_KEY_KANA_MODE → const GhosttyKey
const GhosttyKey(66)
GHOSTTY_KEY_NON_CONVERT → const GhosttyKey
const GhosttyKey(67)
GHOSTTY_KEY_DELETE → const GhosttyKey

Control Pad Section (W3C  3.2)

const GhosttyKey(68)
GHOSTTY_KEY_END → const GhosttyKey
const GhosttyKey(69)
GHOSTTY_KEY_HELP → const GhosttyKey
const GhosttyKey(70)
GHOSTTY_KEY_HOME → const GhosttyKey
const GhosttyKey(71)
GHOSTTY_KEY_INSERT → const GhosttyKey
const GhosttyKey(72)
GHOSTTY_KEY_PAGE_DOWN → const GhosttyKey
const GhosttyKey(73)
GHOSTTY_KEY_PAGE_UP → const GhosttyKey
const GhosttyKey(74)
GHOSTTY_KEY_ARROW_DOWN → const GhosttyKey

Arrow Pad Section (W3C  3.3)

const GhosttyKey(75)
GHOSTTY_KEY_ARROW_LEFT → const GhosttyKey
const GhosttyKey(76)
GHOSTTY_KEY_ARROW_RIGHT → const GhosttyKey
const GhosttyKey(77)
GHOSTTY_KEY_ARROW_UP → const GhosttyKey
const GhosttyKey(78)
GHOSTTY_KEY_NUM_LOCK → const GhosttyKey

Numpad Section (W3C  3.4)

const GhosttyKey(79)
GHOSTTY_KEY_NUMPAD_0 → const GhosttyKey
const GhosttyKey(80)
GHOSTTY_KEY_NUMPAD_1 → const GhosttyKey
const GhosttyKey(81)
GHOSTTY_KEY_NUMPAD_2 → const GhosttyKey
const GhosttyKey(82)
GHOSTTY_KEY_NUMPAD_3 → const GhosttyKey
const GhosttyKey(83)
GHOSTTY_KEY_NUMPAD_4 → const GhosttyKey
const GhosttyKey(84)
GHOSTTY_KEY_NUMPAD_5 → const GhosttyKey
const GhosttyKey(85)
GHOSTTY_KEY_NUMPAD_6 → const GhosttyKey
const GhosttyKey(86)
GHOSTTY_KEY_NUMPAD_7 → const GhosttyKey
const GhosttyKey(87)
GHOSTTY_KEY_NUMPAD_8 → const GhosttyKey
const GhosttyKey(88)
GHOSTTY_KEY_NUMPAD_9 → const GhosttyKey
const GhosttyKey(89)
GHOSTTY_KEY_NUMPAD_ADD → const GhosttyKey
const GhosttyKey(90)
GHOSTTY_KEY_NUMPAD_BACKSPACE → const GhosttyKey
const GhosttyKey(91)
GHOSTTY_KEY_NUMPAD_CLEAR → const GhosttyKey
const GhosttyKey(92)
GHOSTTY_KEY_NUMPAD_CLEAR_ENTRY → const GhosttyKey
const GhosttyKey(93)
GHOSTTY_KEY_NUMPAD_COMMA → const GhosttyKey
const GhosttyKey(94)
GHOSTTY_KEY_NUMPAD_DECIMAL → const GhosttyKey
const GhosttyKey(95)
GHOSTTY_KEY_NUMPAD_DIVIDE → const GhosttyKey
const GhosttyKey(96)
GHOSTTY_KEY_NUMPAD_ENTER → const GhosttyKey
const GhosttyKey(97)
GHOSTTY_KEY_NUMPAD_EQUAL → const GhosttyKey
const GhosttyKey(98)
GHOSTTY_KEY_NUMPAD_MEMORY_ADD → const GhosttyKey
const GhosttyKey(99)
GHOSTTY_KEY_NUMPAD_MEMORY_CLEAR → const GhosttyKey
const GhosttyKey(100)
GHOSTTY_KEY_NUMPAD_MEMORY_RECALL → const GhosttyKey
const GhosttyKey(101)
GHOSTTY_KEY_NUMPAD_MEMORY_STORE → const GhosttyKey
const GhosttyKey(102)
GHOSTTY_KEY_NUMPAD_MEMORY_SUBTRACT → const GhosttyKey
const GhosttyKey(103)
GHOSTTY_KEY_NUMPAD_MULTIPLY → const GhosttyKey
const GhosttyKey(104)
GHOSTTY_KEY_NUMPAD_PAREN_LEFT → const GhosttyKey
const GhosttyKey(105)
GHOSTTY_KEY_NUMPAD_PAREN_RIGHT → const GhosttyKey
const GhosttyKey(106)
GHOSTTY_KEY_NUMPAD_SUBTRACT → const GhosttyKey
const GhosttyKey(107)
GHOSTTY_KEY_NUMPAD_SEPARATOR → const GhosttyKey
const GhosttyKey(108)
GHOSTTY_KEY_NUMPAD_UP → const GhosttyKey
const GhosttyKey(109)
GHOSTTY_KEY_NUMPAD_DOWN → const GhosttyKey
const GhosttyKey(110)
GHOSTTY_KEY_NUMPAD_RIGHT → const GhosttyKey
const GhosttyKey(111)
GHOSTTY_KEY_NUMPAD_LEFT → const GhosttyKey
const GhosttyKey(112)
GHOSTTY_KEY_NUMPAD_BEGIN → const GhosttyKey
const GhosttyKey(113)
GHOSTTY_KEY_NUMPAD_HOME → const GhosttyKey
const GhosttyKey(114)
GHOSTTY_KEY_NUMPAD_END → const GhosttyKey
const GhosttyKey(115)
GHOSTTY_KEY_NUMPAD_INSERT → const GhosttyKey
const GhosttyKey(116)
GHOSTTY_KEY_NUMPAD_DELETE → const GhosttyKey
const GhosttyKey(117)
GHOSTTY_KEY_NUMPAD_PAGE_UP → const GhosttyKey
const GhosttyKey(118)
GHOSTTY_KEY_NUMPAD_PAGE_DOWN → const GhosttyKey
const GhosttyKey(119)
GHOSTTY_KEY_ESCAPE → const GhosttyKey

Function Section (W3C  3.5)

const GhosttyKey(120)
GHOSTTY_KEY_F1 → const GhosttyKey
const GhosttyKey(121)
GHOSTTY_KEY_F2 → const GhosttyKey
const GhosttyKey(122)
GHOSTTY_KEY_F3 → const GhosttyKey
const GhosttyKey(123)
GHOSTTY_KEY_F4 → const GhosttyKey
const GhosttyKey(124)
GHOSTTY_KEY_F5 → const GhosttyKey
const GhosttyKey(125)
GHOSTTY_KEY_F6 → const GhosttyKey
const GhosttyKey(126)
GHOSTTY_KEY_F7 → const GhosttyKey
const GhosttyKey(127)
GHOSTTY_KEY_F8 → const GhosttyKey
const GhosttyKey(128)
GHOSTTY_KEY_F9 → const GhosttyKey
const GhosttyKey(129)
GHOSTTY_KEY_F10 → const GhosttyKey
const GhosttyKey(130)
GHOSTTY_KEY_F11 → const GhosttyKey
const GhosttyKey(131)
GHOSTTY_KEY_F12 → const GhosttyKey
const GhosttyKey(132)
GHOSTTY_KEY_F13 → const GhosttyKey
const GhosttyKey(133)
GHOSTTY_KEY_F14 → const GhosttyKey
const GhosttyKey(134)
GHOSTTY_KEY_F15 → const GhosttyKey
const GhosttyKey(135)
GHOSTTY_KEY_F16 → const GhosttyKey
const GhosttyKey(136)
GHOSTTY_KEY_F17 → const GhosttyKey
const GhosttyKey(137)
GHOSTTY_KEY_F18 → const GhosttyKey
const GhosttyKey(138)
GHOSTTY_KEY_F19 → const GhosttyKey
const GhosttyKey(139)
GHOSTTY_KEY_F20 → const GhosttyKey
const GhosttyKey(140)
GHOSTTY_KEY_F21 → const GhosttyKey
const GhosttyKey(141)
GHOSTTY_KEY_F22 → const GhosttyKey
const GhosttyKey(142)
GHOSTTY_KEY_F23 → const GhosttyKey
const GhosttyKey(143)
GHOSTTY_KEY_F24 → const GhosttyKey
const GhosttyKey(144)
GHOSTTY_KEY_F25 → const GhosttyKey
const GhosttyKey(145)
GHOSTTY_KEY_FN → const GhosttyKey
const GhosttyKey(146)
GHOSTTY_KEY_FN_LOCK → const GhosttyKey
const GhosttyKey(147)
GHOSTTY_KEY_PRINT_SCREEN → const GhosttyKey
const GhosttyKey(148)
GHOSTTY_KEY_SCROLL_LOCK → const GhosttyKey
const GhosttyKey(149)
GHOSTTY_KEY_PAUSE → const GhosttyKey
const GhosttyKey(150)
GHOSTTY_KEY_BROWSER_BACK → const GhosttyKey

Media Keys (W3C  3.6)

const GhosttyKey(151)
GHOSTTY_KEY_BROWSER_FAVORITES → const GhosttyKey
const GhosttyKey(152)
GHOSTTY_KEY_BROWSER_FORWARD → const GhosttyKey
const GhosttyKey(153)
GHOSTTY_KEY_BROWSER_HOME → const GhosttyKey
const GhosttyKey(154)
GHOSTTY_KEY_BROWSER_REFRESH → const GhosttyKey
const GhosttyKey(155)
const GhosttyKey(156)
GHOSTTY_KEY_BROWSER_STOP → const GhosttyKey
const GhosttyKey(157)
GHOSTTY_KEY_EJECT → const GhosttyKey
const GhosttyKey(158)
GHOSTTY_KEY_LAUNCH_APP_1 → const GhosttyKey
const GhosttyKey(159)
GHOSTTY_KEY_LAUNCH_APP_2 → const GhosttyKey
const GhosttyKey(160)
GHOSTTY_KEY_LAUNCH_MAIL → const GhosttyKey
const GhosttyKey(161)
GHOSTTY_KEY_MEDIA_PLAY_PAUSE → const GhosttyKey
const GhosttyKey(162)
GHOSTTY_KEY_MEDIA_SELECT → const GhosttyKey
const GhosttyKey(163)
GHOSTTY_KEY_MEDIA_STOP → const GhosttyKey
const GhosttyKey(164)
GHOSTTY_KEY_MEDIA_TRACK_NEXT → const GhosttyKey
const GhosttyKey(165)
GHOSTTY_KEY_MEDIA_TRACK_PREVIOUS → const GhosttyKey
const GhosttyKey(166)
GHOSTTY_KEY_POWER → const GhosttyKey
const GhosttyKey(167)
GHOSTTY_KEY_SLEEP → const GhosttyKey
const GhosttyKey(168)
GHOSTTY_KEY_AUDIO_VOLUME_DOWN → const GhosttyKey
const GhosttyKey(169)
GHOSTTY_KEY_AUDIO_VOLUME_MUTE → const GhosttyKey
const GhosttyKey(170)
GHOSTTY_KEY_AUDIO_VOLUME_UP → const GhosttyKey
const GhosttyKey(171)
GHOSTTY_KEY_WAKE_UP → const GhosttyKey
const GhosttyKey(172)
GHOSTTY_KEY_COPY → const GhosttyKey

Legacy, Non-standard, and Special Keys (W3C  3.7)

const GhosttyKey(173)
GHOSTTY_KEY_CUT → const GhosttyKey
const GhosttyKey(174)
GHOSTTY_KEY_PASTE → const GhosttyKey
const GhosttyKey(175)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyKey

Constants

values → const List<GhosttyKey>
A constant List of the values in this enum, in order of their declaration.