GhosttyKeyAction enum

Keyboard input event types.

@ingroup key

Inheritance
Available extensions

Values

GHOSTTY_KEY_ACTION_RELEASE → const GhosttyKeyAction

Key was released

const GhosttyKeyAction(0)
GHOSTTY_KEY_ACTION_PRESS → const GhosttyKeyAction

Key was pressed

const GhosttyKeyAction(1)
GHOSTTY_KEY_ACTION_REPEAT → const GhosttyKeyAction

Key is being repeated (held down)

const GhosttyKeyAction(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyKeyAction

Constants

values → const List<GhosttyKeyAction>
A constant List of the values in this enum, in order of their declaration.