GhosttyKeyEncoderOption enum

Key encoder option identifiers.

These values are used with ghostty_key_encoder_setopt() to configure the behavior of the key encoder.

@ingroup key

Inheritance
Available extensions

Values

GHOSTTY_KEY_ENCODER_OPT_CURSOR_KEY_APPLICATION → const GhosttyKeyEncoderOption

Terminal DEC mode 1: cursor key application mode (value: bool)

const GhosttyKeyEncoderOption(0)
GHOSTTY_KEY_ENCODER_OPT_KEYPAD_KEY_APPLICATION → const GhosttyKeyEncoderOption

Terminal DEC mode 66: keypad key application mode (value: bool)

const GhosttyKeyEncoderOption(1)
GHOSTTY_KEY_ENCODER_OPT_IGNORE_KEYPAD_WITH_NUMLOCK → const GhosttyKeyEncoderOption

Terminal DEC mode 1035: ignore keypad with numlock (value: bool)

const GhosttyKeyEncoderOption(2)
GHOSTTY_KEY_ENCODER_OPT_ALT_ESC_PREFIX → const GhosttyKeyEncoderOption

Terminal DEC mode 1036: alt sends escape prefix (value: bool)

const GhosttyKeyEncoderOption(3)
GHOSTTY_KEY_ENCODER_OPT_MODIFY_OTHER_KEYS_STATE_2 → const GhosttyKeyEncoderOption

xterm modifyOtherKeys mode 2 (value: bool)

const GhosttyKeyEncoderOption(4)
GHOSTTY_KEY_ENCODER_OPT_KITTY_FLAGS → const GhosttyKeyEncoderOption

Kitty keyboard protocol flags (value: GhosttyKittyKeyFlags bitmask)

const GhosttyKeyEncoderOption(5)
GHOSTTY_KEY_ENCODER_OPT_MACOS_OPTION_AS_ALT → const GhosttyKeyEncoderOption

macOS option-as-alt setting (value: GhosttyOptionAsAlt)

const GhosttyKeyEncoderOption(6)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyKeyEncoderOption

Constants

values → const List<GhosttyKeyEncoderOption>
A constant List of the values in this enum, in order of their declaration.