GhosttyKeyEvent typedef

GhosttyKeyEvent = Pointer<GhosttyKeyEventImpl>

Opaque handle to a key event.

This handle represents a keyboard input event containing information about the physical key pressed, modifiers, and generated text.

@ingroup key

Implementation

typedef GhosttyKeyEvent = ffi.Pointer<GhosttyKeyEventImpl>;