GhosttyKittyGraphics typedef
Opaque handle to a Kitty graphics image storage.
Obtained via ghostty_terminal_get() with GHOSTTY_TERMINAL_DATA_KITTY_GRAPHICS. The pointer is borrowed from the terminal and remains valid until the next mutating terminal call (e.g. ghostty_terminal_vt_write() or ghostty_terminal_reset()).
@ingroup kitty_graphics
Implementation
typedef GhosttyKittyGraphics = ffi.Pointer<GhosttyKittyGraphicsImpl>;