GhosttyKittyGraphicsPlacementIteratorOption enum
Settable options for ghostty_kitty_graphics_placement_iterator_set().
@ingroup kitty_graphics
Values
- GHOSTTY_KITTY_GRAPHICS_PLACEMENT_ITERATOR_OPTION_LAYER → const GhosttyKittyGraphicsPlacementIteratorOption
-
Set the z-layer filter for the iterator.
Input type: GhosttyKittyPlacementLayer *
const GhosttyKittyGraphicsPlacementIteratorOption(0) - GHOSTTY_KITTY_GRAPHICS_PLACEMENT_ITERATOR_OPTION_MAX_VALUE → const GhosttyKittyGraphicsPlacementIteratorOption
-
const GhosttyKittyGraphicsPlacementIteratorOption(2147483647)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
-
values
→ const List<
GhosttyKittyGraphicsPlacementIteratorOption> - A constant List of the values in this enum, in order of their declaration.