GhosttyKittyImageCompression enum

Compression of a Kitty graphics image.

Note that stored images are always decompressed: GHOSTTY_KITTY_IMAGE_COMPRESSION_ZLIB_DEFLATE payloads are inflated before storage, so ghostty_kitty_graphics_image_get() always reports GHOSTTY_KITTY_IMAGE_COMPRESSION_NONE. Consumers never need to inflate image data themselves.

@ingroup kitty_graphics

Inheritance
Available extensions

Values

GHOSTTY_KITTY_IMAGE_COMPRESSION_NONE → const GhosttyKittyImageCompression
const GhosttyKittyImageCompression(0)
GHOSTTY_KITTY_IMAGE_COMPRESSION_ZLIB_DEFLATE → const GhosttyKittyImageCompression
const GhosttyKittyImageCompression(1)
GHOSTTY_KITTY_IMAGE_COMPRESSION_MAX_VALUE → const GhosttyKittyImageCompression
const GhosttyKittyImageCompression(2147483647)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyKittyImageCompression

Constants

values → const List<GhosttyKittyImageCompression>
A constant List of the values in this enum, in order of their declaration.