GhosttyKittyImageFormat enum

Pixel format of a Kitty graphics image.

Note that stored images are always fully decoded: GHOSTTY_KITTY_IMAGE_FORMAT_PNG is never returned by ghostty_kitty_graphics_image_get() because PNG payloads are decoded to GHOSTTY_KITTY_IMAGE_FORMAT_RGBA before storage. The PNG value exists only for protocol-level completeness.

@ingroup kitty_graphics

Inheritance
Available extensions

Values

GHOSTTY_KITTY_IMAGE_FORMAT_RGB → const GhosttyKittyImageFormat
const GhosttyKittyImageFormat(0)
GHOSTTY_KITTY_IMAGE_FORMAT_RGBA → const GhosttyKittyImageFormat
const GhosttyKittyImageFormat(1)
GHOSTTY_KITTY_IMAGE_FORMAT_PNG → const GhosttyKittyImageFormat
const GhosttyKittyImageFormat(2)
GHOSTTY_KITTY_IMAGE_FORMAT_GRAY_ALPHA → const GhosttyKittyImageFormat
const GhosttyKittyImageFormat(3)
GHOSTTY_KITTY_IMAGE_FORMAT_GRAY → const GhosttyKittyImageFormat
const GhosttyKittyImageFormat(4)
GHOSTTY_KITTY_IMAGE_FORMAT_MAX_VALUE → const GhosttyKittyImageFormat
const GhosttyKittyImageFormat(2147483647)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyKittyImageFormat

Constants

values → const List<GhosttyKittyImageFormat>
A constant List of the values in this enum, in order of their declaration.