GhosttyMouseAction enum
Mouse event action type.
@ingroup mouse
Values
- GHOSTTY_MOUSE_ACTION_PRESS → const GhosttyMouseAction
-
Mouse button was pressed.
const GhosttyMouseAction(0) - GHOSTTY_MOUSE_ACTION_RELEASE → const GhosttyMouseAction
-
Mouse button was released.
const GhosttyMouseAction(1) - GHOSTTY_MOUSE_ACTION_MOTION → const GhosttyMouseAction
-
Mouse moved.
const GhosttyMouseAction(2)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → GhosttyMouseAction
Constants
-
values
→ const List<
GhosttyMouseAction> - A constant List of the values in this enum, in order of their declaration.