GhosttyMouseButton enum
Mouse button identity.
@ingroup mouse
Values
- GHOSTTY_MOUSE_BUTTON_UNKNOWN → const GhosttyMouseButton
-
const GhosttyMouseButton(0) - GHOSTTY_MOUSE_BUTTON_LEFT → const GhosttyMouseButton
-
const GhosttyMouseButton(1) - GHOSTTY_MOUSE_BUTTON_RIGHT → const GhosttyMouseButton
-
const GhosttyMouseButton(2) - GHOSTTY_MOUSE_BUTTON_MIDDLE → const GhosttyMouseButton
-
const GhosttyMouseButton(3) - GHOSTTY_MOUSE_BUTTON_FOUR → const GhosttyMouseButton
-
const GhosttyMouseButton(4) - GHOSTTY_MOUSE_BUTTON_FIVE → const GhosttyMouseButton
-
const GhosttyMouseButton(5) - GHOSTTY_MOUSE_BUTTON_SIX → const GhosttyMouseButton
-
const GhosttyMouseButton(6) - GHOSTTY_MOUSE_BUTTON_SEVEN → const GhosttyMouseButton
-
const GhosttyMouseButton(7) - GHOSTTY_MOUSE_BUTTON_EIGHT → const GhosttyMouseButton
-
const GhosttyMouseButton(8) - GHOSTTY_MOUSE_BUTTON_NINE → const GhosttyMouseButton
-
const GhosttyMouseButton(9) - GHOSTTY_MOUSE_BUTTON_TEN → const GhosttyMouseButton
-
const GhosttyMouseButton(10) - GHOSTTY_MOUSE_BUTTON_ELEVEN → const GhosttyMouseButton
-
const GhosttyMouseButton(11)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → GhosttyMouseButton
Constants
-
values
→ const List<
GhosttyMouseButton> - A constant List of the values in this enum, in order of their declaration.