GhosttyMouseEncoderOption enum

Mouse encoder option identifiers.

These values are used with ghostty_mouse_encoder_setopt() to configure the behavior of the mouse encoder.

@ingroup mouse

Inheritance
Available extensions

Values

GHOSTTY_MOUSE_ENCODER_OPT_EVENT → const GhosttyMouseEncoderOption

Mouse tracking mode (value: GhosttyMouseTrackingMode).

const GhosttyMouseEncoderOption(0)
GHOSTTY_MOUSE_ENCODER_OPT_FORMAT → const GhosttyMouseEncoderOption

Mouse output format (value: GhosttyMouseFormat).

const GhosttyMouseEncoderOption(1)
GHOSTTY_MOUSE_ENCODER_OPT_SIZE → const GhosttyMouseEncoderOption

Renderer size context (value: GhosttyMouseEncoderSize).

const GhosttyMouseEncoderOption(2)
GHOSTTY_MOUSE_ENCODER_OPT_ANY_BUTTON_PRESSED → const GhosttyMouseEncoderOption

Whether any mouse button is currently pressed (value: bool).

const GhosttyMouseEncoderOption(3)
GHOSTTY_MOUSE_ENCODER_OPT_TRACK_LAST_CELL → const GhosttyMouseEncoderOption

Whether to enable motion deduplication by last cell (value: bool).

const GhosttyMouseEncoderOption(4)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyMouseEncoderOption

Constants

values → const List<GhosttyMouseEncoderOption>
A constant List of the values in this enum, in order of their declaration.