GhosttyMouseFormat enum
Mouse output format.
@ingroup mouse
Values
- GHOSTTY_MOUSE_FORMAT_X10 → const GhosttyMouseFormat
-
const GhosttyMouseFormat(0) - GHOSTTY_MOUSE_FORMAT_UTF8 → const GhosttyMouseFormat
-
const GhosttyMouseFormat(1) - GHOSTTY_MOUSE_FORMAT_SGR → const GhosttyMouseFormat
-
const GhosttyMouseFormat(2) - GHOSTTY_MOUSE_FORMAT_URXVT → const GhosttyMouseFormat
-
const GhosttyMouseFormat(3) - GHOSTTY_MOUSE_FORMAT_SGR_PIXELS → const GhosttyMouseFormat
-
const GhosttyMouseFormat(4)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → GhosttyMouseFormat
Constants
-
values
→ const List<
GhosttyMouseFormat> - A constant List of the values in this enum, in order of their declaration.