GhosttyMouseTrackingMode enum

Mouse tracking mode.

@ingroup mouse

Inheritance
Available extensions

Values

GHOSTTY_MOUSE_TRACKING_NONE → const GhosttyMouseTrackingMode

Mouse reporting disabled.

const GhosttyMouseTrackingMode(0)
GHOSTTY_MOUSE_TRACKING_X10 → const GhosttyMouseTrackingMode

X10 mouse mode.

const GhosttyMouseTrackingMode(1)
GHOSTTY_MOUSE_TRACKING_NORMAL → const GhosttyMouseTrackingMode

Normal mouse mode (button press/release only).

const GhosttyMouseTrackingMode(2)
GHOSTTY_MOUSE_TRACKING_BUTTON → const GhosttyMouseTrackingMode

Button-event tracking mode.

const GhosttyMouseTrackingMode(3)
GHOSTTY_MOUSE_TRACKING_ANY → const GhosttyMouseTrackingMode

Any-event tracking mode.

const GhosttyMouseTrackingMode(4)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyMouseTrackingMode

Constants

values → const List<GhosttyMouseTrackingMode>
A constant List of the values in this enum, in order of their declaration.