GhosttyOptimizeMode enum

Build optimization mode.

Inheritance
Available extensions

Values

GHOSTTY_OPTIMIZE_DEBUG → const GhosttyOptimizeMode
const GhosttyOptimizeMode(0)
GHOSTTY_OPTIMIZE_RELEASE_SAFE → const GhosttyOptimizeMode
const GhosttyOptimizeMode(1)
GHOSTTY_OPTIMIZE_RELEASE_SMALL → const GhosttyOptimizeMode
const GhosttyOptimizeMode(2)
GHOSTTY_OPTIMIZE_RELEASE_FAST → const GhosttyOptimizeMode
const GhosttyOptimizeMode(3)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyOptimizeMode

Constants

values → const List<GhosttyOptimizeMode>
A constant List of the values in this enum, in order of their declaration.