GhosttyPoint class final

Tagged union for a point in the terminal grid.

@ingroup point

Inheritance
Implemented types
Available extensions

Constructors

GhosttyPoint()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag GhosttyPointTag
no setter
tagAsInt int
getter/setter pair
value GhosttyPointValue
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited