GhosttyRenderStateColors class final

Render-state color information.

This struct uses the sized-struct ABI pattern. Initialize with GHOSTTY_INIT_SIZED(GhosttyRenderStateColors) before calling ghostty_render_state_colors_get().

Example: @code GhosttyRenderStateColors colors = GHOSTTY_INIT_SIZED(GhosttyRenderStateColors); GhosttyResult result = ghostty_render_state_colors_get(state, &colors); @endcode

@ingroup render

Inheritance
Implemented types
Available extensions

Constructors

GhosttyRenderStateColors()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
background GhosttyColorRgb
The default/current background color for the render state.
getter/setter pair
cursor GhosttyColorRgb
The cursor color when explicitly set by terminal state.
getter/setter pair
cursor_has_value bool
True when cursor contains a valid explicit cursor color value. If this is false, the cursor color should be ignored; it will contain undefined data.
getter/setter pair
foreground GhosttyColorRgb
The default/current foreground color for the render state.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
palette Array<GhosttyColorRgb>
The active 256-color palette for this render state.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
Size of this struct in bytes. Must be set to sizeof(GhosttyRenderStateColors).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited