GhosttyRenderStateCursorVisualStyle enum

Visual style of the cursor.

@ingroup render

Inheritance
Available extensions

Values

GHOSTTY_RENDER_STATE_CURSOR_VISUAL_STYLE_BAR → const GhosttyRenderStateCursorVisualStyle

Bar cursor (DECSCUSR 5, 6).

const GhosttyRenderStateCursorVisualStyle(0)
GHOSTTY_RENDER_STATE_CURSOR_VISUAL_STYLE_BLOCK → const GhosttyRenderStateCursorVisualStyle

Block cursor (DECSCUSR 1, 2).

const GhosttyRenderStateCursorVisualStyle(1)
GHOSTTY_RENDER_STATE_CURSOR_VISUAL_STYLE_UNDERLINE → const GhosttyRenderStateCursorVisualStyle

Underline cursor (DECSCUSR 3, 4).

const GhosttyRenderStateCursorVisualStyle(2)
GHOSTTY_RENDER_STATE_CURSOR_VISUAL_STYLE_BLOCK_HOLLOW → const GhosttyRenderStateCursorVisualStyle

Hollow block cursor.

const GhosttyRenderStateCursorVisualStyle(3)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GhosttyRenderStateCursorVisualStyle>
A constant List of the values in this enum, in order of their declaration.