GhosttyRenderStateDirty enum

Dirty state of a render state after update.

@ingroup render

Inheritance
Available extensions

Values

GHOSTTY_RENDER_STATE_DIRTY_FALSE → const GhosttyRenderStateDirty

Not dirty at all; rendering can be skipped.

const GhosttyRenderStateDirty(0)
GHOSTTY_RENDER_STATE_DIRTY_PARTIAL → const GhosttyRenderStateDirty

Some rows changed; renderer can redraw incrementally.

const GhosttyRenderStateDirty(1)
GHOSTTY_RENDER_STATE_DIRTY_FULL → const GhosttyRenderStateDirty

Global state changed; renderer should redraw everything.

const GhosttyRenderStateDirty(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyRenderStateDirty

Constants

values → const List<GhosttyRenderStateDirty>
A constant List of the values in this enum, in order of their declaration.