GhosttyRowData enum

Row data types.

These values specify what type of data to extract from a row using ghostty_row_get.

@ingroup screen

Inheritance
Available extensions

Values

GHOSTTY_ROW_DATA_INVALID → const GhosttyRowData

Invalid data type. Never results in any data extraction.

const GhosttyRowData(0)
GHOSTTY_ROW_DATA_WRAP → const GhosttyRowData

Whether this row is soft-wrapped.

Output type: bool *

const GhosttyRowData(1)
GHOSTTY_ROW_DATA_WRAP_CONTINUATION → const GhosttyRowData

Whether this row is a continuation of a soft-wrapped row.

Output type: bool *

const GhosttyRowData(2)
GHOSTTY_ROW_DATA_GRAPHEME → const GhosttyRowData

Whether any cells in this row have grapheme clusters.

Output type: bool *

const GhosttyRowData(3)
GHOSTTY_ROW_DATA_STYLED → const GhosttyRowData

Whether any cells in this row have styling (may have false positives).

Output type: bool *

const GhosttyRowData(4)

Whether any cells in this row have hyperlinks (may have false positives).

Output type: bool *

const GhosttyRowData(5)
GHOSTTY_ROW_DATA_SEMANTIC_PROMPT → const GhosttyRowData

The semantic prompt state of this row.

Output type: GhosttyRowSemanticPrompt *

const GhosttyRowData(6)
GHOSTTY_ROW_DATA_KITTY_VIRTUAL_PLACEHOLDER → const GhosttyRowData

Whether this row contains a Kitty virtual placeholder.

Output type: bool *

const GhosttyRowData(7)
GHOSTTY_ROW_DATA_DIRTY → const GhosttyRowData

Whether this row is dirty and requires a redraw.

Output type: bool *

const GhosttyRowData(8)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyRowData

Constants

values → const List<GhosttyRowData>
A constant List of the values in this enum, in order of their declaration.