GhosttySgrAttribute class final

SGR attribute (tagged union).

A complete SGR attribute with both its type tag and associated value. Always check the tag field to determine which value union member is valid.

Attributes without associated data (e.g., GHOSTTY_SGR_ATTR_BOLD) can be identified by tag alone; the value union is not used for these and the memory in the value field is undefined.

@ingroup sgr

Inheritance
Implemented types
Available extensions

Constructors

GhosttySgrAttribute()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag GhosttySgrAttributeTag
no setter
tagAsInt int
getter/setter pair
value GhosttySgrAttributeValue
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited