GhosttySgrAttributeValue class final

SGR attribute value union.

This union contains all possible attribute values. Use the tag field to determine which union member is active. Attributes without associated data (like bold, italic) don't use the union value.

@ingroup sgr

Inheritance
Implemented types
Available extensions

Constructors

GhosttySgrAttributeValue()

Properties

address Pointer<T>

Available on T, provided by the UnionAddress extension

The memory address of the underlying data.
no setter
bg_256 int
getter/setter pair
bg_8 int
getter/setter pair
bright_bg_8 int
getter/setter pair
bright_fg_8 int
getter/setter pair
direct_color_bg GhosttyColorRgb
getter/setter pair
direct_color_fg GhosttyColorRgb
getter/setter pair
fg_256 int
getter/setter pair
fg_8 int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
underline GhosttySgrUnderline
no setter
underline_color GhosttyColorRgb
getter/setter pair
underline_color_256 int
getter/setter pair
underlineAsInt int
getter/setter pair
unknown GhosttySgrUnknown
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited