GhosttySgrUnknown class final

Unknown SGR attribute data.

Contains the full parameter list and the partial list where parsing encountered an unknown or invalid sequence.

@ingroup sgr

Inheritance
Implemented types
Available extensions

Constructors

GhosttySgrUnknown()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
full_len int
getter/setter pair
full_ptr Pointer<Uint16>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
partial_len int
getter/setter pair
partial_ptr Pointer<Uint16>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited