GhosttySizeReportSize class final
Terminal size information for encoding size reports.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - cell_height ↔ int
-
Height of a single terminal cell in pixels.
getter/setter pair
- cell_width ↔ int
-
Width of a single terminal cell in pixels.
getter/setter pair
- columns ↔ int
-
Terminal column count in cells.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- rows ↔ int
-
Terminal row count in cells.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited