GhosttyString class final

A borrowed byte string (pointer + length).

The memory is not owned by this struct. The pointer is only valid for the lifetime documented by the API that produces or consumes it.

Inheritance
Implemented types
Available extensions

Constructors

GhosttyString()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
len int
Length of the string in bytes.
getter/setter pair
ptr Pointer<Uint8>
Pointer to the string bytes.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited