GhosttyStyle class final

Terminal cell style.

Describes the complete visual style for a terminal cell, including foreground, background, and underline colors, as well as text decoration flags. The underline field uses the same values as GhosttySgrUnderline.

This is a sized struct. Use GHOSTTY_INIT_SIZED() to initialize it.

@ingroup style

Inheritance
Implemented types
Available extensions

Constructors

GhosttyStyle()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bg_color GhosttyStyleColor
getter/setter pair
getter/setter pair
bold bool
getter/setter pair
faint bool
getter/setter pair
fg_color GhosttyStyleColor
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inverse bool
getter/setter pair
invisible bool
getter/setter pair
italic bool
getter/setter pair
overline bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
getter/setter pair
strikethrough bool
getter/setter pair
underline int
< One of GHOSTTY_SGR_UNDERLINE_* values
getter/setter pair
underline_color GhosttyStyleColor
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited