GhosttySurfacePosition class final

A surface-space position in pixels.

This is not a terminal grid coordinate. It represents an x/y position in the rendered surface coordinate space, with (0, 0) at the top-left of the surface.

Inheritance
Implemented types
Available extensions

Constructors

GhosttySurfacePosition()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
X position in surface pixels.
getter/setter pair
y double
Y position in surface pixels.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited