GhosttySysImage class final

Result of decoding an image.

The data buffer must be allocated through the allocator provided to the decode callback. The library takes ownership and will free it with the same allocator.

Inheritance
Implemented types
Available extensions

Constructors

GhosttySysImage()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
data Pointer<Uint8>
Pointer to the decoded RGBA pixel data.
getter/setter pair
data_len int
Length of the pixel data in bytes.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
Image height in pixels.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
Image width in pixels.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited