GhosttySysLogFn typedef
Callback type for logging.
When installed, internal library log messages are delivered through this callback instead of being discarded. The embedder is responsible for formatting and routing log output.
@p scope is the log scope name as UTF-8 bytes (e.g. "osc", "kitty"). When the log is unscoped (default scope), @p scope_len is 0.
All pointer arguments are only valid for the duration of the callback. The callback must be safe to call from any thread.
@param userdata The userdata pointer set via GHOSTTY_SYS_OPT_USERDATA @param level The severity level of the log message @param scope Pointer to the scope name bytes @param scope_len Length of the scope name in bytes @param message Pointer to the log message bytes @param message_len Length of the log message in bytes
Implementation
typedef GhosttySysLogFn =
ffi.Pointer<ffi.NativeFunction<GhosttySysLogFnFunction>>;