GhosttySysLogLevel enum

Log severity levels for the log callback.

Inheritance
Available extensions

Values

GHOSTTY_SYS_LOG_LEVEL_ERROR → const GhosttySysLogLevel
const GhosttySysLogLevel(0)
GHOSTTY_SYS_LOG_LEVEL_WARNING → const GhosttySysLogLevel
const GhosttySysLogLevel(1)
GHOSTTY_SYS_LOG_LEVEL_INFO → const GhosttySysLogLevel
const GhosttySysLogLevel(2)
GHOSTTY_SYS_LOG_LEVEL_DEBUG → const GhosttySysLogLevel
const GhosttySysLogLevel(3)
GHOSTTY_SYS_LOG_LEVEL_MAX_VALUE → const GhosttySysLogLevel
const GhosttySysLogLevel(2147483647)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttySysLogLevel

Constants

values → const List<GhosttySysLogLevel>
A constant List of the values in this enum, in order of their declaration.