GhosttyTerminalCompressionMode enum

Amount of compression work to perform before returning.

@ingroup terminal

Inheritance
Available extensions

Values

GHOSTTY_TERMINAL_COMPRESSION_MODE_INCREMENTAL → const GhosttyTerminalCompressionMode

Perform one bounded compression step suitable for idle scheduling.

const GhosttyTerminalCompressionMode(0)
GHOSTTY_TERMINAL_COMPRESSION_MODE_FULL → const GhosttyTerminalCompressionMode

Synchronously inspect every currently eligible page.

const GhosttyTerminalCompressionMode(1)
GHOSTTY_TERMINAL_COMPRESSION_MODE_MAX_VALUE → const GhosttyTerminalCompressionMode
const GhosttyTerminalCompressionMode(2147483647)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyTerminalCompressionMode

Constants

values → const List<GhosttyTerminalCompressionMode>
A constant List of the values in this enum, in order of their declaration.