GhosttyTerminalCompressionResult enum

Scheduling result from terminal compression.

@ingroup terminal

Inheritance
Available extensions

Values

GHOSTTY_TERMINAL_COMPRESSION_RESULT_UNSUPPORTED → const GhosttyTerminalCompressionResult

Retained-mapping reclamation is unavailable on this target.

const GhosttyTerminalCompressionResult(0)
GHOSTTY_TERMINAL_COMPRESSION_RESULT_PENDING → const GhosttyTerminalCompressionResult

More incremental compression work remains.

const GhosttyTerminalCompressionResult(1)
GHOSTTY_TERMINAL_COMPRESSION_RESULT_COMPLETE → const GhosttyTerminalCompressionResult

The pass has no continuation to schedule.

const GhosttyTerminalCompressionResult(2)
GHOSTTY_TERMINAL_COMPRESSION_RESULT_MAX_VALUE → const GhosttyTerminalCompressionResult
const GhosttyTerminalCompressionResult(2147483647)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyTerminalCompressionResult

Constants

values → const List<GhosttyTerminalCompressionResult>
A constant List of the values in this enum, in order of their declaration.