GhosttyTerminalCursorStyle enum

Visual style of the terminal cursor.

@ingroup terminal

Inheritance
Available extensions

Values

GHOSTTY_TERMINAL_CURSOR_STYLE_BAR → const GhosttyTerminalCursorStyle

Bar cursor (DECSCUSR 5, 6).

const GhosttyTerminalCursorStyle(0)
GHOSTTY_TERMINAL_CURSOR_STYLE_BLOCK → const GhosttyTerminalCursorStyle

Block cursor (DECSCUSR 1, 2).

const GhosttyTerminalCursorStyle(1)
GHOSTTY_TERMINAL_CURSOR_STYLE_UNDERLINE → const GhosttyTerminalCursorStyle

Underline cursor (DECSCUSR 3, 4).

const GhosttyTerminalCursorStyle(2)
GHOSTTY_TERMINAL_CURSOR_STYLE_BLOCK_HOLLOW → const GhosttyTerminalCursorStyle

Hollow block cursor.

const GhosttyTerminalCursorStyle(3)
GHOSTTY_TERMINAL_CURSOR_STYLE_MAX_VALUE → const GhosttyTerminalCursorStyle
const GhosttyTerminalCursorStyle(2147483647)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyTerminalCursorStyle

Constants

values → const List<GhosttyTerminalCursorStyle>
A constant List of the values in this enum, in order of their declaration.