GhosttyTerminalDesktopNotification class final

A request to show a desktop notification.

This is a sized struct. The callback must only access fields present in the size reported by size. Both strings are borrowed and valid only for the duration of the callback.

@ingroup terminal

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
body GhosttyString
Notification body.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
Size of this struct in bytes.
getter/setter pair
title GhosttyString
Notification title, or an empty string when the protocol omits it.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited