GhosttyTerminalModeConfig class final

A terminal mode and boolean value used for mode configuration and queries.

For GHOSTTY_TERMINAL_DATA_MODE, initialize mode before calling ghostty_terminal_get(). On success, value contains the current mode value.

This struct has a frozen layout and will not gain fields in future versions.

@ingroup terminal

Inheritance
Implemented types
Available extensions

Constructors

GhosttyTerminalModeConfig()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
mode int
Mode to configure or query.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value bool
Value to set, or the current value returned by a query.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited