GhosttyTerminalProgressReport class final

A progress report emitted by the running program.

This is a sized struct. The callback must only access fields present in the size reported by size.

@ingroup terminal

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
progress int
Progress percentage from 0 through 100, or -1 when omitted.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
Size of this struct in bytes.
getter/setter pair
state GhosttyTerminalProgressState
no setter
stateAsInt int
Literal progress state reported by the running program.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited