GhosttyTerminalProgressState enum

State of a terminal progress report.

@ingroup terminal

Inheritance
Available extensions

Values

GHOSTTY_TERMINAL_PROGRESS_STATE_REMOVE → const GhosttyTerminalProgressState

Remove any visible progress indication.

const GhosttyTerminalProgressState(0)
GHOSTTY_TERMINAL_PROGRESS_STATE_SET → const GhosttyTerminalProgressState

Show determinate progress.

const GhosttyTerminalProgressState(1)
GHOSTTY_TERMINAL_PROGRESS_STATE_ERROR → const GhosttyTerminalProgressState

Show a failed progress state.

const GhosttyTerminalProgressState(2)
GHOSTTY_TERMINAL_PROGRESS_STATE_INDETERMINATE → const GhosttyTerminalProgressState

Show indeterminate progress.

const GhosttyTerminalProgressState(3)
GHOSTTY_TERMINAL_PROGRESS_STATE_PAUSE → const GhosttyTerminalProgressState

Show paused progress.

const GhosttyTerminalProgressState(4)
GHOSTTY_TERMINAL_PROGRESS_STATE_MAX_VALUE → const GhosttyTerminalProgressState
const GhosttyTerminalProgressState(2147483647)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyTerminalProgressState

Constants

values → const List<GhosttyTerminalProgressState>
A constant List of the values in this enum, in order of their declaration.