GhosttyTerminalScreen enum

Terminal screen identifier.

Identifies which screen buffer is active in the terminal.

@ingroup terminal

Inheritance
Available extensions

Values

GHOSTTY_TERMINAL_SCREEN_PRIMARY → const GhosttyTerminalScreen

The primary (normal) screen.

const GhosttyTerminalScreen(0)
GHOSTTY_TERMINAL_SCREEN_ALTERNATE → const GhosttyTerminalScreen

The alternate screen.

const GhosttyTerminalScreen(1)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyTerminalScreen

Constants

values → const List<GhosttyTerminalScreen>
A constant List of the values in this enum, in order of their declaration.