GhosttyTerminalScrollViewportValue class final

Scroll viewport value.

@ingroup terminal

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the UnionAddress extension

The memory address of the underlying data.
no setter
delta int
Scroll delta (only used with GHOSTTY_SCROLL_VIEWPORT_DELTA). Up is negative.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited