GhosttyTerminalScrollbar class final

Scrollbar state for the terminal viewport.

Represents the scrollable area dimensions needed to render a scrollbar.

@ingroup terminal

Inheritance
Implemented types
Available extensions

Constructors

GhosttyTerminalScrollbar()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
len int
Length of the visible area in rows.
getter/setter pair
offset int
Offset into the total area that the viewport is at.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
Total size of the scrollable area in rows.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited