GhosttyTerminalSelectionFormatOptions class final

Options for one-shot formatting of a terminal selection.

This is a sized struct. Use GHOSTTY_INIT_SIZED() to initialize it.

If selection is NULL, the terminal's current active selection is used. If selection is non-NULL, that caller-provided snapshot selection is used.

The selection is formatted from the terminal's active screen using the same formatting semantics as GhosttyFormatter. For copy/clipboard behavior matching Ghostty's Screen.selectionString(), use plain output with unwrap and trim both set to true.

@ingroup selection

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
emit GhosttyFormatterFormat
no setter
emitAsInt int
Output format to emit.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection Pointer<GhosttySelection>
Optional selection to format.
getter/setter pair
size int
Size of this struct in bytes. Must be set to sizeof(GhosttyTerminalSelectionFormatOptions).
getter/setter pair
trim bool
Whether to trim trailing whitespace on non-blank lines.
getter/setter pair
unwrap bool
Whether to unwrap soft-wrapped lines.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited