selection property

Pointer<GhosttySelection> selection
getter/setter pair

Optional selection to format.

If NULL, the terminal's current active selection is used. If the terminal has no active selection, formatting returns GHOSTTY_NO_VALUE.

If non-NULL, the pointed-to selection must be a valid snapshot selection for this terminal and must obey GhosttySelection lifetime rules.

Implementation

external ffi.Pointer<GhosttySelection> selection;