GhosttyTerminalSizeFn typedef

Callback function type for size queries (XTWINOPS).

Called in response to XTWINOPS size queries (CSI 14/16/18 t). Return true and fill *out_size with the current terminal geometry, or return false to silently ignore the query.

@param terminal The terminal handle @param userdata The userdata pointer set via GHOSTTY_TERMINAL_OPT_USERDATA @paramout out_size Pointer to store the terminal size information @return true if size was filled, false to ignore the query

@ingroup terminal

Implementation

typedef GhosttyTerminalSizeFn =
    ffi.Pointer<ffi.NativeFunction<GhosttyTerminalSizeFnFunction>>;