GhosttyTerminalUnknownStringSequence class final

An unsupported string terminal sequence.

The content is borrowed and valid only for the callback duration. It contains the bytes between the sequence introducer and terminator, may contain arbitrary binary data, and is not null-terminated.

@ingroup terminal

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
content GhosttyString
Retained sequence content.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
truncated bool
Whether content was shortened by the byte limit or allocation failure.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited