ghostty_key_event_get_composing function

  1. @Native<Bool Function(GhosttyKeyEvent)>(GhosttyKeyEvent)>()
bool ghostty_key_event_get_composing(
  1. GhosttyKeyEvent event
)

Get whether the key event is part of a composition sequence.

@param event The key event handle, must not be NULL @return Whether the key event is part of a composition sequence

@ingroup key

Implementation

@ffi.Native<ffi.Bool Function(GhosttyKeyEvent)>()
external bool ghostty_key_event_get_composing(GhosttyKeyEvent event);