ghostty_osc_next function

  1. @Native<Void Function(GhosttyOscParser, Uint8)>(GhosttyOscParser, ffi.Uint8)>()
void ghostty_osc_next(
  1. GhosttyOscParser parser,
  2. int byte
)

Parse the next byte in an OSC sequence.

Processes a single byte as part of an OSC sequence. The parser maintains internal state to track the progress through the sequence. Call this function for each byte in the sequence data.

When finished pumping the parser with bytes, call ghostty_osc_end to get the final result.

@param parser The parser handle, must not be null. @param byte The next byte to parse

@ingroup osc

Implementation

@ffi.Native<ffi.Void Function(GhosttyOscParser, ffi.Uint8)>()
external void ghostty_osc_next(GhosttyOscParser parser, int byte);