ghostty_selection_gesture_reset function

  1. @Native<Void Function(GhosttySelectionGesture, GhosttyTerminal)>(GhosttySelectionGesture, GhosttyTerminal)>()
void ghostty_selection_gesture_reset(
  1. GhosttySelectionGesture gesture,
  2. GhosttyTerminal terminal
)

Reset any active selection gesture state.

This cancels the active click sequence and releases any tracked terminal references owned by the gesture without freeing the gesture object. Passing NULL is allowed and is a no-op.

@param gesture Selection gesture handle to reset @param terminal Terminal used to release tracked gesture state

@ingroup selection

Implementation

@ffi.Native<ffi.Void Function(GhosttySelectionGesture, GhosttyTerminal)>()
external void ghostty_selection_gesture_reset(
  GhosttySelectionGesture gesture,
  GhosttyTerminal terminal,
);