ghostty_sgr_attribute_value function

  1. @Native<Pointer<GhosttySgrAttributeValue> Function(Pointer<GhosttySgrAttribute>)>(ffi.Pointer<GhosttySgrAttribute>)>()
Pointer<GhosttySgrAttributeValue> ghostty_sgr_attribute_value(
  1. Pointer<GhosttySgrAttribute> attr
)

Get the value from an SGR attribute.

This function returns a pointer to the value union from an SGR attribute. Use the tag to determine which field of the union is valid. Primarily useful in WebAssembly environments where accessing struct fields directly is difficult.

@param attr Pointer to the SGR attribute @return Pointer to the attribute value union

@ingroup sgr

Implementation

@ffi.Native<
  ffi.Pointer<GhosttySgrAttributeValue> Function(
    ffi.Pointer<GhosttySgrAttribute>,
  )
>()
external ffi.Pointer<GhosttySgrAttributeValue> ghostty_sgr_attribute_value(
  ffi.Pointer<GhosttySgrAttribute> attr,
);