ghostty_sgr_next function

  1. @Native<Bool Function(GhosttySgrParser, Pointer<GhosttySgrAttribute>)>(GhosttySgrParser, ffi.Pointer<GhosttySgrAttribute>)>()
bool ghostty_sgr_next(
  1. GhosttySgrParser parser,
  2. Pointer<GhosttySgrAttribute> attr
)

Get the next SGR attribute.

Parses and returns the next attribute from the parameter list. Call this function repeatedly until it returns false to process all attributes in the sequence.

@param parser The parser handle, must not be NULL @param attr Pointer to store the next attribute @return true if an attribute was returned, false if no more attributes

@ingroup sgr

Implementation

@ffi.Native<
  ffi.Bool Function(GhosttySgrParser, ffi.Pointer<GhosttySgrAttribute>)
>()
external bool ghostty_sgr_next(
  GhosttySgrParser parser,
  ffi.Pointer<GhosttySgrAttribute> attr,
);