ghostty_sgr_reset function

  1. @Native<Void Function(GhosttySgrParser)>(GhosttySgrParser)>()
void ghostty_sgr_reset(
  1. GhosttySgrParser parser
)

Reset an SGR parser instance to the beginning of the parameter list.

Resets the parser's iteration state without clearing the parameters. After calling this, ghostty_sgr_next() will start from the beginning of the parameter list again.

@param parser The parser handle to reset, must not be NULL

@ingroup sgr

Implementation

@ffi.Native<ffi.Void Function(GhosttySgrParser)>()
external void ghostty_sgr_reset(GhosttySgrParser parser);