ghostty_sgr_unknown_full function

  1. @Native<Size Function(GhosttySgrUnknown, Pointer<Pointer<Uint16>>)>(GhosttySgrUnknown, ffi.Pointer<ffi.Pointer<ffi.Uint16>>)>()
int ghostty_sgr_unknown_full(
  1. GhosttySgrUnknown unknown,
  2. Pointer<Pointer<Uint16>> ptr
)

Get the full parameter list from an unknown SGR attribute.

This function retrieves the full parameter list that was provided to the parser when an unknown attribute was encountered. Primarily useful in WebAssembly environments where accessing struct fields directly is difficult.

@param unknown The unknown attribute data @param ptr Pointer to store the pointer to the parameter array (may be NULL) @return The length of the full parameter array

@ingroup sgr

Implementation

@ffi.Native<
  ffi.Size Function(GhosttySgrUnknown, ffi.Pointer<ffi.Pointer<ffi.Uint16>>)
>()
external int ghostty_sgr_unknown_full(
  GhosttySgrUnknown unknown,
  ffi.Pointer<ffi.Pointer<ffi.Uint16>> ptr,
);