ghostty_style_is_default function

  1. @Native<Bool Function(Pointer<GhosttyStyle>)>(ffi.Pointer<GhosttyStyle>)>()
bool ghostty_style_is_default(
  1. Pointer<GhosttyStyle> style
)

Check if a style is the default style.

Returns true if all colors are unset and all flags are off.

@param style Pointer to the style to check @return true if the style is the default style

@ingroup style

Implementation

@ffi.Native<ffi.Bool Function(ffi.Pointer<GhosttyStyle>)>()
external bool ghostty_style_is_default(ffi.Pointer<GhosttyStyle> style);