ghostty_vte_bindings_generated
library
Functions
-
ghostty_alloc(Pointer<GhosttyAllocator> allocator, int len)
→ Pointer<Uint8>
-
Allocate a buffer of
len bytes.
-
ghostty_build_info(GhosttyBuildInfo data, Pointer<Void> out)
→ GhosttyResult
-
-
ghostty_cell_get(DartGhosttyCell cell, GhosttyCellData data, Pointer<Void> out)
→ GhosttyResult
-
-
ghostty_cell_get_multi(DartGhosttyCell cell, int count, Pointer<UnsignedInt> keys, Pointer<Pointer<Void>> values, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_color_contrast(Pointer<GhosttyColorRgb> a, Pointer<GhosttyColorRgb> b)
→ double
-
Calculate the WCAG contrast ratio between two RGB colors.
-
ghostty_color_luminance(Pointer<GhosttyColorRgb> color)
→ double
-
Calculate W3C relative luminance for an RGB color.
-
ghostty_color_palette_default(Pointer<GhosttyColorRgb> out)
→ void
-
Get Ghostty's built-in default 256-color palette.
-
ghostty_color_palette_generate(Pointer<GhosttyColorRgb> base, Pointer<GhosttyColorPaletteMask> skip, Pointer<GhosttyColorRgb> bg, Pointer<GhosttyColorRgb> fg, bool harmonious, Pointer<GhosttyColorRgb> out)
→ void
-
Generate a 256-color palette from base colors.
-
ghostty_color_parse(Pointer<Char> value, int len, Pointer<GhosttyColorRgb> out)
→ GhosttyResult
-
-
ghostty_color_parse_palette_entry(Pointer<Char> value, int len, Pointer<Uint8> out_index, Pointer<GhosttyColorRgb> out_rgb)
→ GhosttyResult
-
-
ghostty_color_parse_x11(Pointer<Char> name, int len, Pointer<GhosttyColorRgb> out)
→ GhosttyResult
-
-
ghostty_color_perceived_luminance(Pointer<GhosttyColorRgb> color)
→ double
-
Calculate perceived luminance for an RGB color.
-
ghostty_color_rgb_get(Pointer<GhosttyColorRgb> color, Pointer<Uint8> r, Pointer<Uint8> g, Pointer<Uint8> b)
→ void
-
Get the RGB color components.
-
ghostty_color_scheme_report_encode(GhosttyColorScheme scheme, Pointer<Char> buf, int buf_len, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_color_x11_name_count()
→ int
-
Get the number of X11 color name entries.
-
ghostty_color_x11_names()
→ Pointer<GhosttyColorX11Entry>
-
Get Ghostty's X11 color name table.
-
ghostty_focus_encode(GhosttyFocusEvent event, Pointer<Char> buf, int buf_len, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_formatter_format(GhosttyFormatter formatter, GhosttyWriter writer)
→ GhosttyResult
-
-
ghostty_formatter_format_alloc(GhosttyFormatter formatter, Pointer<GhosttyAllocator> allocator, Pointer<Pointer<Uint8>> out_ptr, Pointer<Size> out_len)
→ GhosttyResult
-
-
ghostty_formatter_format_buf(GhosttyFormatter formatter, Pointer<Uint8> buf, int buf_len, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_formatter_free(GhosttyFormatter formatter)
→ void
-
Free a formatter instance.
-
ghostty_formatter_terminal_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyFormatter> formatter, GhosttyTerminal terminal, GhosttyFormatterTerminalOptions options)
→ GhosttyResult
-
-
ghostty_free(Pointer<GhosttyAllocator> allocator, Pointer<Uint8> ptr, int len)
→ void
-
Free memory that was allocated by a libghostty-vt function.
-
ghostty_grid_ref_cell(Pointer<GhosttyGridRef> ref, Pointer<GhosttyCell> out_cell)
→ GhosttyResult
-
-
ghostty_grid_ref_graphemes(Pointer<GhosttyGridRef> ref, Pointer<Uint32> buf, int buf_len, Pointer<Size> out_len)
→ GhosttyResult
-
-
ghostty_grid_ref_hyperlink_uri(Pointer<GhosttyGridRef> ref, Pointer<Uint8> buf, int buf_len, Pointer<Size> out_len)
→ GhosttyResult
-
-
ghostty_grid_ref_row(Pointer<GhosttyGridRef> ref, Pointer<GhosttyCell> out_row)
→ GhosttyResult
-
-
ghostty_grid_ref_style(Pointer<GhosttyGridRef> ref, Pointer<GhosttyStyle> out_style)
→ GhosttyResult
-
-
ghostty_key_encoder_encode(GhosttyKeyEncoder encoder, GhosttyKeyEvent event, Pointer<Char> out_buf, int out_buf_size, Pointer<Size> out_len)
→ GhosttyResult
-
-
ghostty_key_encoder_free(GhosttyKeyEncoder encoder)
→ void
-
Free a key encoder instance.
-
ghostty_key_encoder_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyKeyEncoder> encoder)
→ GhosttyResult
-
-
ghostty_key_encoder_setopt(GhosttyKeyEncoder encoder, GhosttyKeyEncoderOption option, Pointer<Void> value)
→ void
-
-
ghostty_key_encoder_setopt_from_terminal(GhosttyKeyEncoder encoder, GhosttyTerminal terminal)
→ void
-
Set encoder options from a terminal's current state.
-
ghostty_key_event_free(GhosttyKeyEvent event)
→ void
-
Free a key event instance.
-
ghostty_key_event_get_action(GhosttyKeyEvent event)
→ GhosttyKeyAction
-
-
ghostty_key_event_get_composing(GhosttyKeyEvent event)
→ bool
-
Get whether the key event is part of a composition sequence.
-
ghostty_key_event_get_consumed_mods(GhosttyKeyEvent event)
→ int
-
Get the consumed modifiers bitmask.
-
ghostty_key_event_get_key(GhosttyKeyEvent event)
→ GhosttyKey
-
-
ghostty_key_event_get_mods(GhosttyKeyEvent event)
→ int
-
Get the modifier keys bitmask.
-
ghostty_key_event_get_unshifted_codepoint(GhosttyKeyEvent event)
→ int
-
Get the unshifted Unicode codepoint.
-
ghostty_key_event_get_utf8(GhosttyKeyEvent event, Pointer<Size> len)
→ Pointer<Char>
-
Get the UTF-8 text generated by the key event.
-
ghostty_key_event_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyKeyEvent> event)
→ GhosttyResult
-
-
ghostty_key_event_set_action(GhosttyKeyEvent event, GhosttyKeyAction action)
→ void
-
-
ghostty_key_event_set_composing(GhosttyKeyEvent event, bool composing)
→ void
-
Set whether the key event is part of a composition sequence.
-
ghostty_key_event_set_consumed_mods(GhosttyKeyEvent event, int consumed_mods)
→ void
-
Set the consumed modifiers bitmask.
-
ghostty_key_event_set_key(GhosttyKeyEvent event, GhosttyKey key)
→ void
-
-
ghostty_key_event_set_mods(GhosttyKeyEvent event, int mods)
→ void
-
Set the modifier keys bitmask.
-
ghostty_key_event_set_unshifted_codepoint(GhosttyKeyEvent event, int codepoint)
→ void
-
Set the unshifted Unicode codepoint.
-
ghostty_key_event_set_utf8(GhosttyKeyEvent event, Pointer<Char> utf8, int len)
→ void
-
Set the UTF-8 text generated by the key for the current keyboard layout.
-
ghostty_kitty_graphics_get(GhosttyKittyGraphics graphics, GhosttyKittyGraphicsData data, Pointer<Void> out)
→ GhosttyResult
-
-
ghostty_kitty_graphics_image(GhosttyKittyGraphics graphics, int image_id)
→ GhosttyKittyGraphicsImage
-
Look up a Kitty graphics image by its image ID.
-
ghostty_kitty_graphics_image_get(GhosttyKittyGraphicsImage image, GhosttyKittyGraphicsImageData data, Pointer<Void> out)
→ GhosttyResult
-
-
ghostty_kitty_graphics_image_get_multi(GhosttyKittyGraphicsImage image, int count, Pointer<UnsignedInt> keys, Pointer<Pointer<Void>> values, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_kitty_graphics_placement_get(GhosttyKittyGraphicsPlacementIterator iterator, GhosttyKittyGraphicsPlacementData data, Pointer<Void> out)
→ GhosttyResult
-
-
ghostty_kitty_graphics_placement_get_multi(GhosttyKittyGraphicsPlacementIterator iterator, int count, Pointer<UnsignedInt> keys, Pointer<Pointer<Void>> values, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_kitty_graphics_placement_grid_size(GhosttyKittyGraphicsPlacementIterator iterator, GhosttyKittyGraphicsImage image, GhosttyTerminal terminal, Pointer<Uint32> out_cols, Pointer<Uint32> out_rows)
→ GhosttyResult
-
-
ghostty_kitty_graphics_placement_iterator_free(GhosttyKittyGraphicsPlacementIterator iterator)
→ void
-
Free a placement iterator.
-
ghostty_kitty_graphics_placement_iterator_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyKittyGraphicsPlacementIterator> out_iterator)
→ GhosttyResult
-
-
ghostty_kitty_graphics_placement_iterator_set(GhosttyKittyGraphicsPlacementIterator iterator, GhosttyKittyGraphicsPlacementIteratorOption option, Pointer<Void> value)
→ GhosttyResult
-
-
ghostty_kitty_graphics_placement_next(GhosttyKittyGraphicsPlacementIterator iterator)
→ bool
-
Advance the placement iterator to the next placement.
-
ghostty_kitty_graphics_placement_pixel_size(GhosttyKittyGraphicsPlacementIterator iterator, GhosttyKittyGraphicsImage image, GhosttyTerminal terminal, Pointer<Uint32> out_width, Pointer<Uint32> out_height)
→ GhosttyResult
-
-
ghostty_kitty_graphics_placement_rect(GhosttyKittyGraphicsPlacementIterator iterator, GhosttyKittyGraphicsImage image, GhosttyTerminal terminal, Pointer<GhosttySelection> out_selection)
→ GhosttyResult
-
-
ghostty_kitty_graphics_placement_render_info(GhosttyKittyGraphicsPlacementIterator iterator, GhosttyKittyGraphicsImage image, GhosttyTerminal terminal, Pointer<GhosttyKittyGraphicsPlacementRenderInfo> out_info)
→ GhosttyResult
-
-
ghostty_kitty_graphics_placement_source_rect(GhosttyKittyGraphicsPlacementIterator iterator, GhosttyKittyGraphicsImage image, Pointer<Uint32> out_x, Pointer<Uint32> out_y, Pointer<Uint32> out_width, Pointer<Uint32> out_height)
→ GhosttyResult
-
-
ghostty_kitty_graphics_placement_viewport_pos(GhosttyKittyGraphicsPlacementIterator iterator, GhosttyKittyGraphicsImage image, GhosttyTerminal terminal, Pointer<Int32> out_col, Pointer<Int32> out_row)
→ GhosttyResult
-
-
ghostty_mode_report_encode(DartGhosttyMode mode, GhosttyModeReportState state, Pointer<Char> buf, int buf_len, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_mouse_encoder_encode(GhosttyMouseEncoder encoder, GhosttyMouseEvent event, Pointer<Char> out_buf, int out_buf_size, Pointer<Size> out_len)
→ GhosttyResult
-
-
ghostty_mouse_encoder_free(GhosttyMouseEncoder encoder)
→ void
-
Free a mouse encoder instance.
-
ghostty_mouse_encoder_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyMouseEncoder> encoder)
→ GhosttyResult
-
-
ghostty_mouse_encoder_reset(GhosttyMouseEncoder encoder)
→ void
-
Reset internal encoder state.
-
ghostty_mouse_encoder_setopt(GhosttyMouseEncoder encoder, GhosttyMouseEncoderOption option, Pointer<Void> value)
→ void
-
-
ghostty_mouse_encoder_setopt_from_terminal(GhosttyMouseEncoder encoder, GhosttyTerminal terminal)
→ void
-
Set encoder options from a terminal's current state.
-
ghostty_mouse_event_clear_button(GhosttyMouseEvent event)
→ void
-
Clear the event button.
-
ghostty_mouse_event_free(GhosttyMouseEvent event)
→ void
-
Free a mouse event instance.
-
ghostty_mouse_event_get_action(GhosttyMouseEvent event)
→ GhosttyMouseAction
-
-
ghostty_mouse_event_get_button(GhosttyMouseEvent event, Pointer<UnsignedInt> out_button)
→ bool
-
Get the event button.
-
ghostty_mouse_event_get_mods(GhosttyMouseEvent event)
→ int
-
Get keyboard modifiers held during the event.
-
ghostty_mouse_event_get_position(GhosttyMouseEvent event)
→ GhosttyMousePosition
-
Get the event position in surface-space pixels.
-
ghostty_mouse_event_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyMouseEvent> event)
→ GhosttyResult
-
-
ghostty_mouse_event_set_action(GhosttyMouseEvent event, GhosttyMouseAction action)
→ void
-
-
ghostty_mouse_event_set_button(GhosttyMouseEvent event, GhosttyMouseButton button)
→ void
-
-
ghostty_mouse_event_set_mods(GhosttyMouseEvent event, int mods)
→ void
-
Set keyboard modifiers held during the event.
-
ghostty_mouse_event_set_position(GhosttyMouseEvent event, GhosttyMousePosition position)
→ void
-
Set the event position in surface-space pixels.
-
ghostty_osc_command_data(GhosttyOscCommand command, GhosttyOscCommandData data, Pointer<Void> out)
→ bool
-
-
ghostty_osc_command_type(GhosttyOscCommand command)
→ GhosttyOscCommandType
-
-
ghostty_osc_end(GhosttyOscParser parser, int terminator)
→ GhosttyOscCommand
-
Finalize OSC parsing and retrieve the parsed command.
-
ghostty_osc_free(GhosttyOscParser parser)
→ void
-
Free an OSC parser instance.
-
ghostty_osc_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyOscParser> parser)
→ GhosttyResult
-
-
ghostty_osc_next(GhosttyOscParser parser, int byte)
→ void
-
Parse the next byte in an OSC sequence.
-
ghostty_osc_reset(GhosttyOscParser parser)
→ void
-
Reset an OSC parser instance to its initial state.
-
ghostty_paste_encode(Pointer<Char> data, int data_len, bool bracketed, Pointer<Char> buf, int buf_len, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_paste_is_safe(Pointer<Char> data, int len)
→ bool
-
Check if paste data is safe to paste into the terminal.
-
ghostty_render_state_begin_update(GhosttyRenderState state, GhosttyTerminal terminal)
→ GhosttyResult
-
-
ghostty_render_state_clean(GhosttyRenderState state)
→ GhosttyResult
-
-
ghostty_render_state_end_update(GhosttyRenderState state)
→ GhosttyResult
-
-
ghostty_render_state_free(GhosttyRenderState state)
→ void
-
Free a render state instance.
-
ghostty_render_state_get(GhosttyRenderState state, GhosttyRenderStateData data, Pointer<Void> out)
→ GhosttyResult
-
-
ghostty_render_state_get_multi(GhosttyRenderState state, int count, Pointer<UnsignedInt> keys, Pointer<Pointer<Void>> values, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_render_state_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyRenderState> state)
→ GhosttyResult
-
-
ghostty_render_state_row_cells_free(GhosttyRenderStateRowCells cells)
→ void
-
Free a row cells instance.
-
ghostty_render_state_row_cells_get(GhosttyRenderStateRowCells cells, GhosttyRenderStateRowCellsData data, Pointer<Void> out)
→ GhosttyResult
-
-
ghostty_render_state_row_cells_get_multi(GhosttyRenderStateRowCells cells, int count, Pointer<UnsignedInt> keys, Pointer<Pointer<Void>> values, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_render_state_row_cells_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyRenderStateRowCells> out_cells)
→ GhosttyResult
-
-
ghostty_render_state_row_cells_next(GhosttyRenderStateRowCells cells)
→ bool
-
Move a render-state row cells iterator to the next cell.
-
ghostty_render_state_row_cells_select(GhosttyRenderStateRowCells cells, int x)
→ GhosttyResult
-
-
ghostty_render_state_row_get(GhosttyRenderStateRowIterator iterator, GhosttyRenderStateRowData data, Pointer<Void> out)
→ GhosttyResult
-
-
ghostty_render_state_row_get_multi(GhosttyRenderStateRowIterator iterator, int count, Pointer<UnsignedInt> keys, Pointer<Pointer<Void>> values, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_render_state_row_iterator_free(GhosttyRenderStateRowIterator iterator)
→ void
-
Free a render-state row iterator.
-
ghostty_render_state_row_iterator_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyRenderStateRowIterator> out_iterator)
→ GhosttyResult
-
-
ghostty_render_state_row_iterator_next(GhosttyRenderStateRowIterator iterator)
→ bool
-
Move a render-state row iterator to the next row.
-
ghostty_render_state_row_iterator_next_dirty(GhosttyRenderStateRowIterator iterator, Pointer<Uint16> out_y)
→ bool
-
Move a render-state row iterator to the next row requiring a redraw.
-
ghostty_render_state_row_set(GhosttyRenderStateRowIterator iterator, GhosttyRenderStateRowOption option, Pointer<Void> value)
→ GhosttyResult
-
-
ghostty_render_state_set(GhosttyRenderState state, GhosttyRenderStateOption option, Pointer<Void> value)
→ GhosttyResult
-
-
ghostty_render_state_update(GhosttyRenderState state, GhosttyTerminal terminal)
→ GhosttyResult
-
-
ghostty_row_get(DartGhosttyRow row, GhosttyRowData data, Pointer<Void> out)
→ GhosttyResult
-
-
ghostty_row_get_multi(DartGhosttyRow row, int count, Pointer<UnsignedInt> keys, Pointer<Pointer<Void>> values, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_selection_gesture_event(GhosttySelectionGesture gesture, GhosttyTerminal terminal, GhosttySelectionGestureEvent event, Pointer<GhosttySelection> out_selection)
→ GhosttyResult
-
-
ghostty_selection_gesture_event_free(GhosttySelectionGestureEvent event)
→ void
-
Free a selection gesture event object.
-
ghostty_selection_gesture_event_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttySelectionGestureEvent> out_event, GhosttySelectionGestureEventType type)
→ GhosttyResult
-
-
ghostty_selection_gesture_event_set(GhosttySelectionGestureEvent event, GhosttySelectionGestureEventOption option, Pointer<Void> value)
→ GhosttyResult
-
-
ghostty_selection_gesture_free(GhosttySelectionGesture gesture, GhosttyTerminal terminal)
→ void
-
Free a selection gesture object.
-
ghostty_selection_gesture_get(GhosttySelectionGesture gesture, GhosttyTerminal terminal, GhosttySelectionGestureData data, Pointer<Void> value)
→ GhosttyResult
-
-
ghostty_selection_gesture_get_multi(GhosttySelectionGesture gesture, GhosttyTerminal terminal, int count, Pointer<UnsignedInt> keys, Pointer<Pointer<Void>> values, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_selection_gesture_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttySelectionGesture> out_gesture)
→ GhosttyResult
-
-
ghostty_selection_gesture_reset(GhosttySelectionGesture gesture, GhosttyTerminal terminal)
→ void
-
Reset any active selection gesture state.
-
ghostty_sgr_attribute_tag(GhosttySgrAttribute attr)
→ GhosttySgrAttributeTag
-
-
ghostty_sgr_attribute_value(Pointer<GhosttySgrAttribute> attr)
→ Pointer<GhosttySgrAttributeValue>
-
Get the value from an SGR attribute.
-
ghostty_sgr_free(GhosttySgrParser parser)
→ void
-
Free an SGR parser instance.
-
ghostty_sgr_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttySgrParser> parser)
→ GhosttyResult
-
-
ghostty_sgr_next(GhosttySgrParser parser, Pointer<GhosttySgrAttribute> attr)
→ bool
-
Get the next SGR attribute.
-
ghostty_sgr_reset(GhosttySgrParser parser)
→ void
-
Reset an SGR parser instance to the beginning of the parameter list.
-
ghostty_sgr_set_params(GhosttySgrParser parser, Pointer<Uint16> params, Pointer<Char> separators, int len)
→ GhosttyResult
-
-
ghostty_sgr_unknown_full(GhosttySgrUnknown unknown, Pointer<Pointer<Uint16>> ptr)
→ int
-
Get the full parameter list from an unknown SGR attribute.
-
ghostty_sgr_unknown_partial(GhosttySgrUnknown unknown, Pointer<Pointer<Uint16>> ptr)
→ int
-
Get the partial parameter list from an unknown SGR attribute.
-
ghostty_size_report_encode(GhosttySizeReportStyle style, GhosttySizeReportSize size, Pointer<Char> buf, int buf_len, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_snapshot_decoder_decode(GhosttySnapshotDecoder decoder, Pointer<GhosttyTerminal> terminal)
→ GhosttyResult
-
-
ghostty_snapshot_decoder_free(GhosttySnapshotDecoder decoder)
→ void
-
Free a snapshot decoder.
-
ghostty_snapshot_decoder_get(GhosttySnapshotDecoder decoder, GhosttySnapshotDecoderData data, Pointer<Void> out)
→ GhosttyResult
-
-
ghostty_snapshot_decoder_get_multi(GhosttySnapshotDecoder decoder, int count, Pointer<UnsignedInt> keys, Pointer<Pointer<Void>> values, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_snapshot_decoder_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttySnapshotDecoder> decoder, GhosttyReader reader)
→ GhosttyResult
-
-
ghostty_snapshot_decoder_new_buf(Pointer<GhosttyAllocator> allocator, Pointer<GhosttySnapshotDecoder> decoder, Pointer<Uint8> ptr, int len)
→ GhosttyResult
-
-
ghostty_snapshot_decoder_next(GhosttySnapshotDecoder decoder)
→ GhosttyResult
-
-
ghostty_snapshot_decoder_ready(GhosttySnapshotDecoder decoder, Pointer<GhosttyTerminal> terminal)
→ GhosttyResult
-
-
ghostty_snapshot_decoder_set(GhosttySnapshotDecoder decoder, GhosttySnapshotDecoderOption option, Pointer<Void> value)
→ GhosttyResult
-
-
ghostty_snapshot_encode(GhosttyTerminal terminal, GhosttyWriter writer)
→ GhosttyResult
-
-
ghostty_snapshot_encode_alloc(GhosttyTerminal terminal, Pointer<GhosttyAllocator> allocator, Pointer<Pointer<Uint8>> out_ptr, Pointer<Size> out_len)
→ GhosttyResult
-
-
ghostty_snapshot_encode_buf(GhosttyTerminal terminal, Pointer<Uint8> buf, int buf_len, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_style_default(Pointer<GhosttyStyle> style)
→ void
-
Get the default style.
-
ghostty_style_is_default(Pointer<GhosttyStyle> style)
→ bool
-
Check if a style is the default style.
-
ghostty_sys_log_stderr(Pointer<Void> userdata, GhosttySysLogLevel level, Pointer<Uint8> scope, int scope_len, Pointer<Uint8> message, int message_len)
→ void
-
-
ghostty_sys_set(GhosttySysOption option, Pointer<Void> value)
→ GhosttyResult
-
-
ghostty_terminal_compress(GhosttyTerminal terminal, GhosttyTerminalCompressionMode mode, Pointer<UnsignedInt> out_result)
→ GhosttyResult
-
-
ghostty_terminal_compression_activity(GhosttyTerminal terminal, Pointer<GhosttyCell> out_activity)
→ GhosttyResult
-
-
ghostty_terminal_continuation_alloc(GhosttyTerminal terminal, Pointer<GhosttyAllocator> allocator, Pointer<Pointer<Uint8>> out_ptr, Pointer<Size> out_len)
→ GhosttyResult
-
-
ghostty_terminal_continuation_buf(GhosttyTerminal terminal, Pointer<Uint8> buf, int buf_len, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_terminal_continuation_write(GhosttyTerminal terminal, GhosttyWriter writer)
→ GhosttyResult
-
-
ghostty_terminal_free(GhosttyTerminal terminal)
→ void
-
Free a terminal instance.
-
ghostty_terminal_get(GhosttyTerminal terminal, GhosttyTerminalData data, Pointer<Void> out)
→ GhosttyResult
-
-
ghostty_terminal_get_multi(GhosttyTerminal terminal, int count, Pointer<UnsignedInt> keys, Pointer<Pointer<Void>> values, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_terminal_grid_ref(GhosttyTerminal terminal, GhosttyPoint point, Pointer<GhosttyGridRef> out_ref)
→ GhosttyResult
-
-
ghostty_terminal_grid_ref_track(GhosttyTerminal terminal, GhosttyPoint point, Pointer<GhosttyTrackedGridRef> out_ref)
→ GhosttyResult
-
-
ghostty_terminal_new(Pointer<GhosttyAllocator> allocator, Pointer<GhosttyTerminal> terminal, int cols, int rows)
→ GhosttyResult
-
-
ghostty_terminal_paste(GhosttyTerminal terminal, Pointer<GhosttyPaste> paste, Pointer<Bool> out_written)
→ GhosttyResult
-
-
ghostty_terminal_point_from_grid_ref(GhosttyTerminal terminal, Pointer<GhosttyGridRef> ref, GhosttyPointTag tag, Pointer<GhosttyPointCoordinate> out)
→ GhosttyResult
-
-
ghostty_terminal_reset(GhosttyTerminal terminal)
→ void
-
Perform a full reset of the terminal (RIS).
-
ghostty_terminal_resize(GhosttyTerminal terminal, int cols, int rows, int cell_width_px, int cell_height_px)
→ GhosttyResult
-
-
ghostty_terminal_scroll_viewport(GhosttyTerminal terminal, GhosttyTerminalScrollViewport behavior)
→ void
-
Scroll the terminal viewport.
-
ghostty_terminal_select_all(GhosttyTerminal terminal, Pointer<GhosttySelection> out_selection)
→ GhosttyResult
-
-
ghostty_terminal_select_line(GhosttyTerminal terminal, Pointer<GhosttyTerminalSelectLineOptions> options, Pointer<GhosttySelection> out_selection)
→ GhosttyResult
-
-
ghostty_terminal_select_output(GhosttyTerminal terminal, GhosttyGridRef ref, Pointer<GhosttySelection> out_selection)
→ GhosttyResult
-
-
ghostty_terminal_select_word(GhosttyTerminal terminal, Pointer<GhosttyTerminalSelectWordOptions> options, Pointer<GhosttySelection> out_selection)
→ GhosttyResult
-
-
ghostty_terminal_select_word_between(GhosttyTerminal terminal, Pointer<GhosttyTerminalSelectWordBetweenOptions> options, Pointer<GhosttySelection> out_selection)
→ GhosttyResult
-
-
ghostty_terminal_selection_adjust(GhosttyTerminal terminal, Pointer<GhosttySelection> selection, GhosttySelectionAdjust adjustment)
→ GhosttyResult
-
-
ghostty_terminal_selection_contains(GhosttyTerminal terminal, Pointer<GhosttySelection> selection, GhosttyPoint point, Pointer<Bool> out_contains)
→ GhosttyResult
-
-
ghostty_terminal_selection_equal(GhosttyTerminal terminal, Pointer<GhosttySelection> a, Pointer<GhosttySelection> b, Pointer<Bool> out_equal)
→ GhosttyResult
-
-
ghostty_terminal_selection_format_alloc(GhosttyTerminal terminal, Pointer<GhosttyAllocator> allocator, GhosttyTerminalSelectionFormatOptions options, Pointer<Pointer<Uint8>> out_ptr, Pointer<Size> out_len)
→ GhosttyResult
-
-
ghostty_terminal_selection_format_buf(GhosttyTerminal terminal, GhosttyTerminalSelectionFormatOptions options, Pointer<Uint8> buf, int buf_len, Pointer<Size> out_written)
→ GhosttyResult
-
-
ghostty_terminal_selection_order(GhosttyTerminal terminal, Pointer<GhosttySelection> selection, Pointer<UnsignedInt> out_order)
→ GhosttyResult
-
-
ghostty_terminal_selection_ordered(GhosttyTerminal terminal, Pointer<GhosttySelection> selection, GhosttySelectionOrder desired, Pointer<GhosttySelection> out_selection)
→ GhosttyResult
-
-
ghostty_terminal_set(GhosttyTerminal terminal, GhosttyTerminalOption option, Pointer<Void> value)
→ GhosttyResult
-
-
ghostty_terminal_vt_write(GhosttyTerminal terminal, Pointer<Uint8> data, int len)
→ void
-
Write VT-encoded data to the terminal for processing.
-
ghostty_terminal_vt_write_until_ground(GhosttyTerminal terminal, Pointer<Uint8> data, int len, Pointer<Size> out_consumed)
→ GhosttyResult
-
-
ghostty_tracked_grid_ref_free(GhosttyTrackedGridRef ref)
→ void
-
Free a tracked grid reference.
-
ghostty_tracked_grid_ref_has_value(GhosttyTrackedGridRef ref)
→ bool
-
Return whether a tracked grid reference currently has a meaningful value.
-
ghostty_tracked_grid_ref_point(GhosttyTrackedGridRef ref, GhosttyPointTag tag, Pointer<GhosttyPointCoordinate> out_point)
→ GhosttyResult
-
-
ghostty_tracked_grid_ref_set(GhosttyTrackedGridRef ref, GhosttyTerminal terminal, GhosttyPoint point)
→ GhosttyResult
-
-
ghostty_tracked_grid_ref_snapshot(GhosttyTrackedGridRef ref, Pointer<GhosttyGridRef> out_ref)
→ GhosttyResult
-
-
ghostty_type_json()
→ Pointer<Char>
-
Return the versioned libghostty-vt C type manifest for the current target.
-
ghostty_unicode_codepoint_width(int cp)
→ int
-
Returns the terminal display width of a Unicode codepoint in
terminal grid cells: 0, 1, or 2.
-
ghostty_unicode_grapheme_width(Pointer<Uint32> cps, int len, Pointer<Uint8> width)
→ int
-
Measures the terminal display width of the first grapheme cluster in a
sequence of Unicode codepoints.
Typedefs
-
DartGhosttyCell
= int
-
-
DartGhosttyClipboardReadReplyFnFunction
= void Function(Pointer<GhosttyClipboardRead> read, Pointer<GhosttyClipboardReadReply> reply)
-
-
DartGhosttyClipboardWriteReplyFnFunction
= void Function(Pointer<GhosttyClipboardWrite> write, Pointer<GhosttyClipboardWriteReply> reply)
-
-
DartGhosttyColorPaletteIndex
= int
-
-
DartGhosttyKittyKeyFlags
= int
-
-
DartGhosttyMimeReaderFnFunction
= bool Function(Pointer<Void> userdata, GhosttyString mime, GhosttyWriter writer)
-
-
DartGhosttyMode
= int
-
-
DartGhosttyMods
= int
-
-
DartGhosttyReaderFnFunction
= bool Function(Pointer<Void> userdata, Pointer<Uint8> buffer, int capacity, Pointer<Size> out_read)
-
-
DartGhosttyRow
= int
-
-
DartGhosttyStyleId
= int
-
-
DartGhosttySysDecodePngFnFunction
= bool Function(Pointer<Void> userdata, Pointer<GhosttyAllocator> allocator, Pointer<Uint8> data, int data_len, Pointer<GhosttySysImage> out)
-
-
DartGhosttySysLogFnFunction
= void Function(Pointer<Void> userdata, GhosttySysLogLevel level, Pointer<Uint8> scope, int scope_len, Pointer<Uint8> message, int message_len)
-
-
DartGhosttySysRandomSecureFnFunction
= bool Function(Pointer<Void> userdata, Pointer<Uint8> buf, int len)
-
-
DartGhosttyTerminalBellFnFunction
= void Function(GhosttyTerminal terminal, Pointer<Void> userdata)
-
-
DartGhosttyTerminalClipboardReadFnFunction
= void Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<GhosttyClipboardRead> read)
-
-
DartGhosttyTerminalClipboardWriteFnFunction
= void Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<GhosttyClipboardWrite> write)
-
-
DartGhosttyTerminalColorSchemeFnFunction
= bool Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<UnsignedInt> out_scheme)
-
-
DartGhosttyTerminalDesktopNotificationFnFunction
= void Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<GhosttyTerminalDesktopNotification> notification)
-
-
DartGhosttyTerminalDeviceAttributesFnFunction
= bool Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<GhosttyDeviceAttributes> out_attrs)
-
-
DartGhosttyTerminalProgressReportFnFunction
= void Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<GhosttyTerminalProgressReport> report)
-
-
DartGhosttyTerminalPwdChangedFnFunction
= void Function(GhosttyTerminal terminal, Pointer<Void> userdata)
-
-
DartGhosttyTerminalSizeFnFunction
= bool Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<GhosttySizeReportSize> out_size)
-
-
DartGhosttyTerminalTitleChangedFnFunction
= void Function(GhosttyTerminal terminal, Pointer<Void> userdata)
-
-
DartGhosttyTerminalUnknownSequenceFnFunction
= void Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<GhosttyTerminalUnknownSequence> sequence)
-
-
DartGhosttyTerminalWritePtyFnFunction
= void Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<Uint8> data, int len)
-
-
DartGhosttyWriterFnFunction
= bool Function(Pointer<Void> userdata, Pointer<Uint8> buf, int len)
-
-
GhosttyCell
= Uint64
-
Packed cell value.
-
GhosttyClipboardReadReplyFn
= Pointer<NativeFunction<GhosttyClipboardReadReplyFnFunction>>
-
Function type used to answer a clipboard read request. Obtained from
GhosttyClipboardRead::reply; see that struct for the contract.
-
GhosttyClipboardReadReplyFnFunction
= Void Function(Pointer<GhosttyClipboardRead> read, Pointer<GhosttyClipboardReadReply> reply)
-
-
GhosttyClipboardWriteReplyFn
= Pointer<NativeFunction<GhosttyClipboardWriteReplyFnFunction>>
-
Function type used to answer a clipboard write request. Obtained from
GhosttyClipboardWrite::reply; see that struct for the contract.
-
GhosttyClipboardWriteReplyFnFunction
= Void Function(Pointer<GhosttyClipboardWrite> write, Pointer<GhosttyClipboardWriteReply> reply)
-
-
GhosttyColorPaletteIndex
= Uint8
-
Palette color index (0-255).
-
GhosttyFormatter
= Pointer<GhosttyFormatterImpl>
-
Opaque handle to a formatter instance.
-
GhosttyKeyEncoder
= Pointer<GhosttyKeyEncoderImpl>
-
Opaque handle to a key encoder instance.
-
GhosttyKeyEvent
= Pointer<GhosttyKeyEventImpl>
-
Opaque handle to a key event.
-
GhosttyKittyGraphics
= Pointer<GhosttyKittyGraphicsImpl>
-
Opaque handle to a Kitty graphics image storage.
-
GhosttyKittyGraphicsImage
= Pointer<GhosttyKittyGraphicsImageImpl>
-
Opaque handle to a Kitty graphics image.
-
GhosttyKittyGraphicsPlacementIterator
= Pointer<GhosttyKittyGraphicsPlacementIteratorImpl>
-
Opaque handle to a Kitty graphics placement iterator.
-
GhosttyKittyKeyFlags
= Uint8
-
Kitty keyboard protocol flags.
-
GhosttyMimeReaderFn
= Pointer<NativeFunction<GhosttyMimeReaderFnFunction>>
-
Read one MIME-typed representation of some content, streaming its
bytes to a writer.
-
GhosttyMimeReaderFnFunction
= Bool Function(Pointer<Void> userdata, GhosttyString mime, GhosttyWriter writer)
-
-
GhosttyMode
= Uint16
-
A packed 16-bit terminal mode.
-
GhosttyMods
= Uint16
-
Keyboard modifier keys bitmask.
-
GhosttyMouseEncoder
= Pointer<GhosttyMouseEncoderImpl>
-
Opaque handle to a mouse encoder instance.
-
GhosttyMouseEvent
= Pointer<GhosttyMouseEventImpl>
-
Opaque handle to a mouse event.
-
GhosttyOscCommand
= Pointer<GhosttyOscCommandImpl>
-
Opaque handle to a single OSC command.
-
GhosttyOscParser
= Pointer<GhosttyOscParserImpl>
-
Opaque handle to an OSC parser instance.
-
GhosttyReaderFn
= Pointer<NativeFunction<GhosttyReaderFnFunction>>
-
Read bytes from a source.
-
GhosttyReaderFnFunction
= Bool Function(Pointer<Void> userdata, Pointer<Uint8> buffer, Size capacity, Pointer<Size> out_read)
-
-
GhosttyRenderState
= Pointer<GhosttyRenderStateImpl>
-
Opaque handle to a render state instance.
-
GhosttyRenderStateRowCells
= Pointer<GhosttyRenderStateRowCellsImpl>
-
Opaque handle to render-state row cells.
-
GhosttyRenderStateRowIterator
= Pointer<GhosttyRenderStateRowIteratorImpl>
-
Opaque handle to a render-state row iterator.
-
GhosttyRow
= Uint64
-
Opaque row value.
-
GhosttySelectionGesture
= Pointer<GhosttySelectionGestureImpl>
-
Opaque handle to state for interpreting terminal selection gestures.
-
GhosttySelectionGestureEvent
= Pointer<GhosttySelectionGestureEventImpl>
-
Opaque handle to reusable input data for selection gesture operations.
-
GhosttySgrParser
= Pointer<GhosttySgrParserImpl>
-
Opaque handle to an SGR parser instance.
-
GhosttySnapshotDecoder
= Pointer<GhosttySnapshotDecoderImpl>
-
Opaque handle to an incremental terminal snapshot decoder.
-
GhosttyStyleId
= Uint16
-
Style identifier type.
-
GhosttySysDecodePngFn
= Pointer<NativeFunction<GhosttySysDecodePngFnFunction>>
-
Callback type for PNG decoding.
-
GhosttySysDecodePngFnFunction
= Bool Function(Pointer<Void> userdata, Pointer<GhosttyAllocator> allocator, Pointer<Uint8> data, Size data_len, Pointer<GhosttySysImage> out)
-
-
GhosttySysLogFn
= Pointer<NativeFunction<GhosttySysLogFnFunction>>
-
Callback type for logging.
-
GhosttySysLogFnFunction
= Void Function(Pointer<Void> userdata, UnsignedInt level, Pointer<Uint8> scope, Size scope_len, Pointer<Uint8> message, Size message_len)
-
-
GhosttySysRandomSecureFn
= Pointer<NativeFunction<GhosttySysRandomSecureFnFunction>>
-
Callback type for secure random bytes.
-
GhosttySysRandomSecureFnFunction
= Bool Function(Pointer<Void> userdata, Pointer<Uint8> buf, Size len)
-
-
GhosttyTerminal
= Pointer<GhosttyTerminalImpl>
-
Opaque handle to a terminal instance.
-
GhosttyTerminalBellFn
= Pointer<NativeFunction<GhosttyTerminalBellFnFunction>>
-
Callback function type for bell.
-
GhosttyTerminalBellFnFunction
= Void Function(GhosttyTerminal terminal, Pointer<Void> userdata)
-
-
GhosttyTerminalClipboardReadFn
= Pointer<NativeFunction<GhosttyTerminalClipboardReadFnFunction>>
-
Callback function type for clipboard_read.
-
GhosttyTerminalClipboardReadFnFunction
= Void Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<GhosttyClipboardRead> read)
-
-
GhosttyTerminalClipboardWriteFn
= Pointer<NativeFunction<GhosttyTerminalClipboardWriteFnFunction>>
-
Callback function type for clipboard_write.
-
GhosttyTerminalClipboardWriteFnFunction
= Void Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<GhosttyClipboardWrite> write)
-
-
GhosttyTerminalColorSchemeFn
= Pointer<NativeFunction<GhosttyTerminalColorSchemeFnFunction>>
-
Callback function type for color scheme queries (CSI ? 996 n).
-
GhosttyTerminalColorSchemeFnFunction
= Bool Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<UnsignedInt> out_scheme)
-
-
GhosttyTerminalDesktopNotificationFn
= Pointer<NativeFunction<GhosttyTerminalDesktopNotificationFnFunction>>
-
Callback function type for desktop notifications.
-
GhosttyTerminalDesktopNotificationFnFunction
= Void Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<GhosttyTerminalDesktopNotification> notification)
-
-
GhosttyTerminalDeviceAttributesFn
= Pointer<NativeFunction<GhosttyTerminalDeviceAttributesFnFunction>>
-
Callback function type for device attributes queries (DA1/DA2/DA3).
-
GhosttyTerminalDeviceAttributesFnFunction
= Bool Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<GhosttyDeviceAttributes> out_attrs)
-
-
GhosttyTerminalEnquiryFn
= Pointer<NativeFunction<GhosttyTerminalEnquiryFnFunction>>
-
Callback function type for enquiry (ENQ, 0x05).
-
GhosttyTerminalEnquiryFnFunction
= GhosttyString Function(GhosttyTerminal terminal, Pointer<Void> userdata)
-
-
GhosttyTerminalProgressReportFn
= Pointer<NativeFunction<GhosttyTerminalProgressReportFnFunction>>
-
Callback function type for progress reports.
-
GhosttyTerminalProgressReportFnFunction
= Void Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<GhosttyTerminalProgressReport> report)
-
-
GhosttyTerminalPwdChangedFn
= Pointer<NativeFunction<GhosttyTerminalBellFnFunction>>
-
Callback function type for pwd_changed.
-
GhosttyTerminalPwdChangedFnFunction
= Void Function(GhosttyTerminal terminal, Pointer<Void> userdata)
-
-
GhosttyTerminalSizeFn
= Pointer<NativeFunction<GhosttyTerminalSizeFnFunction>>
-
Callback function type for terminal size reports.
-
GhosttyTerminalSizeFnFunction
= Bool Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<GhosttySizeReportSize> out_size)
-
-
GhosttyTerminalTitleChangedFn
= Pointer<NativeFunction<GhosttyTerminalBellFnFunction>>
-
Callback function type for title_changed.
-
GhosttyTerminalTitleChangedFnFunction
= Void Function(GhosttyTerminal terminal, Pointer<Void> userdata)
-
-
GhosttyTerminalUnknownSequenceFn
= Pointer<NativeFunction<GhosttyTerminalUnknownSequenceFnFunction>>
-
Callback function type for unsupported terminal sequences.
-
GhosttyTerminalUnknownSequenceFnFunction
= Void Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<GhosttyTerminalUnknownSequence> sequence)
-
-
GhosttyTerminalWritePtyFn
= Pointer<NativeFunction<GhosttyTerminalWritePtyFnFunction>>
-
Callback function type for write_pty.
-
GhosttyTerminalWritePtyFnFunction
= Void Function(GhosttyTerminal terminal, Pointer<Void> userdata, Pointer<Uint8> data, Size len)
-
-
GhosttyTerminalXtversionFn
= Pointer<NativeFunction<GhosttyTerminalEnquiryFnFunction>>
-
Callback function type for XTVERSION.
-
GhosttyTerminalXtversionFnFunction
= GhosttyString Function(GhosttyTerminal terminal, Pointer<Void> userdata)
-
-
GhosttyTrackedGridRef
= Pointer<GhosttyTrackedGridRefImpl>
-
Opaque handle to a tracked grid reference.
-
GhosttyWriterFn
= Pointer<NativeFunction<GhosttySysRandomSecureFnFunction>>
-
Write bytes to a destination.
-
GhosttyWriterFnFunction
= Bool Function(Pointer<Void> userdata, Pointer<Uint8> buf, Size len)
-