GhosttyBuffer class final
A caller-provided byte buffer.
APIs that write to this type use len for the number of bytes written on
GHOSTTY_SUCCESS and the required byte capacity on GHOSTTY_OUT_OF_SPACE.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - cap ↔ int
-
Capacity of ptr in bytes.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- len ↔ int
-
Bytes written on success, or required byte capacity on GHOSTTY_OUT_OF_SPACE.
getter/setter pair
-
ptr
↔ Pointer<
Uint8> -
Destination buffer for bytes. May be NULL when cap is 0 to query required size.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited