GhosttyCellsView class final
A borrowed view of contiguous raw cell values.
The memory is not owned by this struct. The pointer is only valid for the lifetime documented by the API that produces it. Each value can be queried via ghostty_cell_get() or decoded using the GhosttyCell packed descriptor returned by ghostty_type_json().
@ingroup screen
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- len ↔ int
-
Number of cells.
getter/setter pair
-
ptr
↔ Pointer<
GhosttyCell> -
Pointer to len contiguous cell values.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited