GhosttyCodepoints class final
A borrowed list of Unicode scalar values.
Values are encoded as uint32_t scalar values. The memory is not owned by this struct. The pointer is only valid for the lifetime documented by the API that consumes or produces it.
APIs may document special handling for NULL + len 0, such as “use defaults”.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- len ↔ int
-
Number of entries in ptr.
getter/setter pair
-
ptr
↔ Pointer<
Uint32> -
Pointer to Unicode scalar values.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited