GhosttyDeviceAttributesPrimary class final
Primary device attributes (DA1) response data.
Returned as part of GhosttyDeviceAttributes in response to a CSI c query. The conformance_level is the Pp parameter and features contains the Ps feature codes.
@ingroup terminal
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - conformance_level ↔ int
-
Conformance level (Pp parameter). E.g. 62 for VT220.
getter/setter pair
-
features
↔ Array<
Uint16> -
DA1 feature codes. Only the first num_features entries are valid.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- num_features ↔ int
-
Number of valid entries in the features array.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited