GhosttyDeviceAttributesTertiary class final
Tertiary device attributes (DA3) response data.
Returned as part of GhosttyDeviceAttributes in response to a CSI = c query. Response format: DCS ! | D...D ST (DECRPTUI).
@ingroup terminal
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unit_id ↔ int
-
Unit ID encoded as 8 uppercase hex digits in the response.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited