GhosttyFormatterTerminalOptions class final
Options for creating a terminal formatter.
@ingroup formatter
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - emit → GhosttyFormatterFormat
-
no setter
- emitAsInt ↔ int
-
Output format to emit.
getter/setter pair
- extra ↔ GhosttyFormatterTerminalExtra
-
Extra terminal state to include in styled output.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size ↔ int
-
Size of this struct in bytes. Must be set to sizeof(GhosttyFormatterTerminalOptions).
getter/setter pair
- trim ↔ bool
-
Whether to trim trailing whitespace on non-blank lines.
getter/setter pair
- unwrap ↔ bool
-
Whether to unwrap soft-wrapped lines.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited