GhosttyKittyGraphicsPlacementData enum
Queryable data kinds for ghostty_kitty_graphics_placement_get().
@ingroup kitty_graphics
Values
- GHOSTTY_KITTY_GRAPHICS_PLACEMENT_DATA_INVALID → const GhosttyKittyGraphicsPlacementData
-
Invalid / sentinel value.
const GhosttyKittyGraphicsPlacementData(0) - GHOSTTY_KITTY_GRAPHICS_PLACEMENT_DATA_IMAGE_ID → const GhosttyKittyGraphicsPlacementData
-
The image ID this placement belongs to.
Output type: uint32_t *
const GhosttyKittyGraphicsPlacementData(1) - GHOSTTY_KITTY_GRAPHICS_PLACEMENT_DATA_PLACEMENT_ID → const GhosttyKittyGraphicsPlacementData
-
The placement ID.
Output type: uint32_t *
const GhosttyKittyGraphicsPlacementData(2) - GHOSTTY_KITTY_GRAPHICS_PLACEMENT_DATA_IS_VIRTUAL → const GhosttyKittyGraphicsPlacementData
-
Whether this is a virtual placement (unicode placeholder).
Output type: bool *
const GhosttyKittyGraphicsPlacementData(3) - GHOSTTY_KITTY_GRAPHICS_PLACEMENT_DATA_X_OFFSET → const GhosttyKittyGraphicsPlacementData
-
Pixel offset from the left edge of the cell.
Output type: uint32_t *
const GhosttyKittyGraphicsPlacementData(4) - GHOSTTY_KITTY_GRAPHICS_PLACEMENT_DATA_Y_OFFSET → const GhosttyKittyGraphicsPlacementData
-
Pixel offset from the top edge of the cell.
Output type: uint32_t *
const GhosttyKittyGraphicsPlacementData(5) - GHOSTTY_KITTY_GRAPHICS_PLACEMENT_DATA_SOURCE_X → const GhosttyKittyGraphicsPlacementData
-
Source rectangle x origin in pixels.
Output type: uint32_t *
const GhosttyKittyGraphicsPlacementData(6) - GHOSTTY_KITTY_GRAPHICS_PLACEMENT_DATA_SOURCE_Y → const GhosttyKittyGraphicsPlacementData
-
Source rectangle y origin in pixels.
Output type: uint32_t *
const GhosttyKittyGraphicsPlacementData(7) - GHOSTTY_KITTY_GRAPHICS_PLACEMENT_DATA_SOURCE_WIDTH → const GhosttyKittyGraphicsPlacementData
-
Source rectangle width in pixels (0 = full image width).
Output type: uint32_t *
const GhosttyKittyGraphicsPlacementData(8) - GHOSTTY_KITTY_GRAPHICS_PLACEMENT_DATA_SOURCE_HEIGHT → const GhosttyKittyGraphicsPlacementData
-
Source rectangle height in pixels (0 = full image height).
Output type: uint32_t *
const GhosttyKittyGraphicsPlacementData(9) - GHOSTTY_KITTY_GRAPHICS_PLACEMENT_DATA_COLUMNS → const GhosttyKittyGraphicsPlacementData
-
Number of columns this placement occupies.
Output type: uint32_t *
const GhosttyKittyGraphicsPlacementData(10) - GHOSTTY_KITTY_GRAPHICS_PLACEMENT_DATA_ROWS → const GhosttyKittyGraphicsPlacementData
-
Number of rows this placement occupies.
Output type: uint32_t *
const GhosttyKittyGraphicsPlacementData(11) - GHOSTTY_KITTY_GRAPHICS_PLACEMENT_DATA_Z → const GhosttyKittyGraphicsPlacementData
-
Z-index for this placement.
Output type: int32_t *
const GhosttyKittyGraphicsPlacementData(12) - GHOSTTY_KITTY_GRAPHICS_PLACEMENT_DATA_MAX_VALUE → const GhosttyKittyGraphicsPlacementData
-
const GhosttyKittyGraphicsPlacementData(2147483647)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
-
values
→ const List<
GhosttyKittyGraphicsPlacementData> - A constant List of the values in this enum, in order of their declaration.