GhosttyModeReportState enum
DECRPM report state values.
These correspond to the Ps2 parameter in a DECRPM response sequence (CSI ? Ps1 ; Ps2 $ y).
Values
- GHOSTTY_MODE_REPORT_NOT_RECOGNIZED → const GhosttyModeReportState
-
Mode is not recognized
const GhosttyModeReportState(0) - GHOSTTY_MODE_REPORT_SET → const GhosttyModeReportState
-
Mode is set (enabled)
const GhosttyModeReportState(1) - GHOSTTY_MODE_REPORT_RESET → const GhosttyModeReportState
-
Mode is reset (disabled)
const GhosttyModeReportState(2) - GHOSTTY_MODE_REPORT_PERMANENTLY_SET → const GhosttyModeReportState
-
Mode is permanently set
const GhosttyModeReportState(3) - GHOSTTY_MODE_REPORT_PERMANENTLY_RESET → const GhosttyModeReportState
-
Mode is permanently reset
const GhosttyModeReportState(4)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → GhosttyModeReportState
Constants
-
values
→ const List<
GhosttyModeReportState> - A constant List of the values in this enum, in order of their declaration.