GhosttyMouseEncoderSize class final
Mouse encoder size and geometry context.
This describes the rendered terminal geometry used to convert surface-space positions into encoded coordinates.
@ingroup mouse
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - cell_height ↔ int
-
Cell height in pixels. Must be non-zero.
getter/setter pair
- cell_width ↔ int
-
Cell width in pixels. Must be non-zero.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding_bottom ↔ int
-
Bottom padding in pixels.
getter/setter pair
- padding_left ↔ int
-
Left padding in pixels.
getter/setter pair
- padding_right ↔ int
-
Right padding in pixels.
getter/setter pair
- padding_top ↔ int
-
Top padding in pixels.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screen_height ↔ int
-
Full screen height in pixels.
getter/setter pair
- screen_width ↔ int
-
Full screen width in pixels.
getter/setter pair
- size ↔ int
-
Size of this struct in bytes. Must be set to sizeof(GhosttyMouseEncoderSize).
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited