GhosttyOptionAsAlt enum
macOS option key behavior.
Determines whether the "option" key on macOS is treated as "alt" or not.
See the Ghostty macos-option-as-alt configuration option for more details.
@ingroup key
Values
- GHOSTTY_OPTION_AS_ALT_FALSE → const GhosttyOptionAsAlt
-
Option key is not treated as alt
const GhosttyOptionAsAlt(0) - GHOSTTY_OPTION_AS_ALT_TRUE → const GhosttyOptionAsAlt
-
Option key is treated as alt
const GhosttyOptionAsAlt(1) - GHOSTTY_OPTION_AS_ALT_LEFT → const GhosttyOptionAsAlt
-
Only left option key is treated as alt
const GhosttyOptionAsAlt(2) - GHOSTTY_OPTION_AS_ALT_RIGHT → const GhosttyOptionAsAlt
-
Only right option key is treated as alt
const GhosttyOptionAsAlt(3)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → GhosttyOptionAsAlt
Constants
-
values
→ const List<
GhosttyOptionAsAlt> - A constant List of the values in this enum, in order of their declaration.