GhosttyOscCommandData enum
OSC command data types.
These values specify what type of data to extract from an OSC command
using ghostty_osc_command_data.
@ingroup osc
Values
- GHOSTTY_OSC_DATA_INVALID → const GhosttyOscCommandData
-
Invalid data type. Never results in any data extraction.
const GhosttyOscCommandData(0) - GHOSTTY_OSC_DATA_CHANGE_WINDOW_TITLE_STR → const GhosttyOscCommandData
-
Window title string data.
Valid for: GHOSTTY_OSC_COMMAND_CHANGE_WINDOW_TITLE
Output type: const char ** (pointer to null-terminated string)
Lifetime: Valid until the next call to any ghostty_osc_* function with the same parser instance. Memory is owned by the parser.
const GhosttyOscCommandData(1)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → GhosttyOscCommandData
Constants
-
values
→ const List<
GhosttyOscCommandData> - A constant List of the values in this enum, in order of their declaration.