GhosttyRenderStateCursor class final
Render-state cursor information.
This struct uses the sized-struct ABI pattern. Initialize with GHOSTTY_INIT_SIZED(GhosttyRenderStateCursor) before querying GHOSTTY_RENDER_STATE_DATA_CURSOR.
When viewport_has_value is false, viewport_x, viewport_y, and wide_tail contain undefined data and must not be read.
@ingroup render
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - blinking ↔ bool
-
Whether the cursor should blink based on terminal modes.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- password_input ↔ bool
-
Whether the cursor is at a password input field.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size ↔ int
-
Size of this struct in bytes. Must be set to sizeof(GhosttyRenderStateCursor).
getter/setter pair
- viewport_has_value ↔ bool
-
Whether the cursor is visible within the viewport.
getter/setter pair
- viewport_x ↔ int
-
Cursor viewport x position in cells.
getter/setter pair
- viewport_y ↔ int
-
Cursor viewport y position in cells.
getter/setter pair
- visible ↔ bool
-
Whether the cursor is visible based on terminal modes.
getter/setter pair
- visual_style → GhosttyRenderStateCursorVisualStyle
-
no setter
- visual_styleAsInt ↔ int
-
The visual style of the cursor.
getter/setter pair
- wide_tail ↔ bool
-
Whether the cursor is on the tail of a wide character.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited