GhosttyRenderStateData enum
Queryable data kinds for ghostty_render_state_get().
@ingroup render
Values
- GHOSTTY_RENDER_STATE_DATA_INVALID → const GhosttyRenderStateData
-
Invalid / sentinel value.
const GhosttyRenderStateData(0) - GHOSTTY_RENDER_STATE_DATA_COLS → const GhosttyRenderStateData
-
Viewport width in cells (uint16_t).
const GhosttyRenderStateData(1) - GHOSTTY_RENDER_STATE_DATA_ROWS → const GhosttyRenderStateData
-
Viewport height in cells (uint16_t).
const GhosttyRenderStateData(2) - GHOSTTY_RENDER_STATE_DATA_DIRTY → const GhosttyRenderStateData
-
Current dirty state (GhosttyRenderStateDirty).
const GhosttyRenderStateData(3) - GHOSTTY_RENDER_STATE_DATA_ROW_ITERATOR → const GhosttyRenderStateData
-
Populate a pre-allocated GhosttyRenderStateRowIterator with row data from the render state (GhosttyRenderStateRowIterator). Row data is only valid as long as the underlying render state is not updated. It is unsafe to use row data after updating the render state.
const GhosttyRenderStateData(4) - GHOSTTY_RENDER_STATE_DATA_COLOR_BACKGROUND → const GhosttyRenderStateData
-
Default/current background color (GhosttyColorRgb).
const GhosttyRenderStateData(5) - GHOSTTY_RENDER_STATE_DATA_COLOR_FOREGROUND → const GhosttyRenderStateData
-
Default/current foreground color (GhosttyColorRgb).
const GhosttyRenderStateData(6) - GHOSTTY_RENDER_STATE_DATA_COLOR_CURSOR → const GhosttyRenderStateData
-
Cursor color when explicitly set by terminal state (GhosttyColorRgb). Returns GHOSTTY_INVALID_VALUE if no explicit cursor color is set; use COLOR_CURSOR_HAS_VALUE to check first.
const GhosttyRenderStateData(7) - GHOSTTY_RENDER_STATE_DATA_COLOR_CURSOR_HAS_VALUE → const GhosttyRenderStateData
-
Whether an explicit cursor color is set (bool).
const GhosttyRenderStateData(8) - GHOSTTY_RENDER_STATE_DATA_COLOR_PALETTE → const GhosttyRenderStateData
-
The active 256-color palette (
GhosttyColorRgb[256]).const GhosttyRenderStateData(9) - GHOSTTY_RENDER_STATE_DATA_CURSOR_VISUAL_STYLE → const GhosttyRenderStateData
-
The visual style of the cursor (GhosttyRenderStateCursorVisualStyle).
const GhosttyRenderStateData(10) - GHOSTTY_RENDER_STATE_DATA_CURSOR_VISIBLE → const GhosttyRenderStateData
-
Whether the cursor is visible based on terminal modes (bool).
const GhosttyRenderStateData(11) - GHOSTTY_RENDER_STATE_DATA_CURSOR_BLINKING → const GhosttyRenderStateData
-
Whether the cursor should blink based on terminal modes (bool).
const GhosttyRenderStateData(12) - GHOSTTY_RENDER_STATE_DATA_CURSOR_PASSWORD_INPUT → const GhosttyRenderStateData
-
Whether the cursor is at a password input field (bool).
const GhosttyRenderStateData(13) - GHOSTTY_RENDER_STATE_DATA_CURSOR_VIEWPORT_HAS_VALUE → const GhosttyRenderStateData
-
Whether the cursor is visible within the viewport (bool). If false, the cursor viewport position values are undefined.
const GhosttyRenderStateData(14) - GHOSTTY_RENDER_STATE_DATA_CURSOR_VIEWPORT_X → const GhosttyRenderStateData
-
Cursor viewport x position in cells (uint16_t). Only valid when CURSOR_VIEWPORT_HAS_VALUE is true.
const GhosttyRenderStateData(15) - GHOSTTY_RENDER_STATE_DATA_CURSOR_VIEWPORT_Y → const GhosttyRenderStateData
-
Cursor viewport y position in cells (uint16_t). Only valid when CURSOR_VIEWPORT_HAS_VALUE is true.
const GhosttyRenderStateData(16) - GHOSTTY_RENDER_STATE_DATA_CURSOR_VIEWPORT_WIDE_TAIL → const GhosttyRenderStateData
-
Whether the cursor is on the tail of a wide character (bool). Only valid when CURSOR_VIEWPORT_HAS_VALUE is true.
const GhosttyRenderStateData(17)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → GhosttyRenderStateData
Constants
-
values
→ const List<
GhosttyRenderStateData> - A constant List of the values in this enum, in order of their declaration.