GhosttyRenderStateRowData enum

Queryable data kinds for ghostty_render_state_row_get().

@ingroup render

Inheritance
Available extensions

Values

GHOSTTY_RENDER_STATE_ROW_DATA_INVALID → const GhosttyRenderStateRowData

Invalid / sentinel value.

const GhosttyRenderStateRowData(0)
GHOSTTY_RENDER_STATE_ROW_DATA_DIRTY → const GhosttyRenderStateRowData

Whether the current row is dirty (bool).

const GhosttyRenderStateRowData(1)
GHOSTTY_RENDER_STATE_ROW_DATA_RAW → const GhosttyRenderStateRowData

The raw row value (GhosttyRow).

const GhosttyRenderStateRowData(2)
GHOSTTY_RENDER_STATE_ROW_DATA_CELLS → const GhosttyRenderStateRowData

Populate a pre-allocated GhosttyRenderStateRowCells with cell data for the current row (GhosttyRenderStateRowCells). Cell data is only valid as long as the underlying render state is not updated. It is unsafe to use cell data after updating the render state.

const GhosttyRenderStateRowData(3)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyRenderStateRowData

Constants

values → const List<GhosttyRenderStateRowData>
A constant List of the values in this enum, in order of their declaration.