GhosttyRenderStateRowSelection class final
Row-local selection range.
This struct uses the sized-struct ABI pattern. Initialize with GHOSTTY_INIT_SIZED(GhosttyRenderStateRowSelection) before querying GHOSTTY_RENDER_STATE_ROW_DATA_SELECTION.
Querying GHOSTTY_RENDER_STATE_ROW_DATA_SELECTION returns GHOSTTY_NO_VALUE if the current row does not intersect the current selection.
@ingroup render
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - end_x ↔ int
-
End column of the row-local selection range, inclusive.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size ↔ int
-
Size of this struct in bytes. Must be set to sizeof(GhosttyRenderStateRowSelection).
getter/setter pair
- start_x ↔ int
-
Start column of the row-local selection range, inclusive.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited