GhosttyResult enum
Result codes for libghostty-vt operations.
Values
- GHOSTTY_SUCCESS → const GhosttyResult
-
Operation completed successfully
const GhosttyResult(0) - GHOSTTY_OUT_OF_MEMORY → const GhosttyResult
-
Operation failed due to failed allocation
const GhosttyResult(-1) - GHOSTTY_INVALID_VALUE → const GhosttyResult
-
Operation failed due to invalid value
const GhosttyResult(-2) - GHOSTTY_OUT_OF_SPACE → const GhosttyResult
-
Operation failed because the provided buffer was too small
const GhosttyResult(-3) - GHOSTTY_NO_VALUE → const GhosttyResult
-
The requested value has no value
const GhosttyResult(-4)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → GhosttyResult
Constants
-
values
→ const List<
GhosttyResult> - A constant List of the values in this enum, in order of their declaration.