GhosttyResult enum

Result codes for libghostty-vt operations.

Inheritance
Available extensions

Values

GHOSTTY_SUCCESS → const GhosttyResult

Operation completed successfully

const GhosttyResult(0)
GHOSTTY_OUT_OF_MEMORY → const GhosttyResult

Operation failed due to failed allocation

const GhosttyResult(-1)
GHOSTTY_INVALID_VALUE → const GhosttyResult

Operation failed due to invalid value

const GhosttyResult(-2)
GHOSTTY_OUT_OF_SPACE → const GhosttyResult

Operation failed because the provided buffer was too small

const GhosttyResult(-3)
GHOSTTY_NO_VALUE → const GhosttyResult

The requested value has no value

const GhosttyResult(-4)
GHOSTTY_IO_ERROR → const GhosttyResult

Operation failed while reading from or writing to external I/O

const GhosttyResult(-5)
GHOSTTY_LIMIT_EXCEEDED → const GhosttyResult

Operation failed because encoded input exceeded a configured limit

const GhosttyResult(-6)
GHOSTTY_REJECTED → const GhosttyResult

Operation was rejected by a safety check (e.g. pasted text that could inject commands). Nothing was done. Confirm with the user and retry with the operation's allow flag set.

const GhosttyResult(-7)
GHOSTTY_RESULT_MAX_VALUE → const GhosttyResult
const GhosttyResult(2147483647)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GhosttyResult

Constants

values → const List<GhosttyResult>
A constant List of the values in this enum, in order of their declaration.