GhosttyRowSemanticPrompt enum
Row semantic prompt state.
Indicates whether any cells in a row are part of a shell prompt, as reported by OSC 133 sequences.
@ingroup screen
Values
- GHOSTTY_ROW_SEMANTIC_NONE → const GhosttyRowSemanticPrompt
-
No prompt cells in this row.
const GhosttyRowSemanticPrompt(0) - GHOSTTY_ROW_SEMANTIC_PROMPT → const GhosttyRowSemanticPrompt
-
Prompt cells exist and this is a primary prompt line.
const GhosttyRowSemanticPrompt(1) - GHOSTTY_ROW_SEMANTIC_PROMPT_CONTINUATION → const GhosttyRowSemanticPrompt
-
Prompt cells exist and this is a continuation line.
const GhosttyRowSemanticPrompt(2)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → GhosttyRowSemanticPrompt
Constants
-
values
→ const List<
GhosttyRowSemanticPrompt> - A constant List of the values in this enum, in order of their declaration.