GhosttySelectionOrder enum
Ordering of a selection's endpoints in terminal coordinates.
Mirrored orders are only produced by rectangular selections whose start and end endpoints are on opposite diagonal corners that are not simple top-left-to-bottom-right or bottom-right-to-top-left orderings.
@ingroup selection
Values
- GHOSTTY_SELECTION_ORDER_FORWARD → const GhosttySelectionOrder
-
Start is before end in top-left to bottom-right order.
const GhosttySelectionOrder(0) - GHOSTTY_SELECTION_ORDER_REVERSE → const GhosttySelectionOrder
-
End is before start in top-left to bottom-right order.
const GhosttySelectionOrder(1) - GHOSTTY_SELECTION_ORDER_MIRRORED_FORWARD → const GhosttySelectionOrder
-
Rectangular selection from top-right to bottom-left.
const GhosttySelectionOrder(2) - GHOSTTY_SELECTION_ORDER_MIRRORED_REVERSE → const GhosttySelectionOrder
-
Rectangular selection from bottom-left to top-right.
const GhosttySelectionOrder(3) - GHOSTTY_SELECTION_ORDER_MAX_VALUE → const GhosttySelectionOrder
-
const GhosttySelectionOrder(2147483647)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → GhosttySelectionOrder
Constants
-
values
→ const List<
GhosttySelectionOrder> - A constant List of the values in this enum, in order of their declaration.