GhosttySizeReportStyle enum
Size report style.
Determines the output format for the terminal size report.
Values
- GHOSTTY_SIZE_REPORT_MODE_2048 → const GhosttySizeReportStyle
-
In-band size report (mode 2048): ESC [ 48 ; rows ; cols ; height ; width t
const GhosttySizeReportStyle(0) - GHOSTTY_SIZE_REPORT_CSI_14_T → const GhosttySizeReportStyle
-
XTWINOPS text area size in pixels: ESC [ 4 ; height ; width t
const GhosttySizeReportStyle(1) - GHOSTTY_SIZE_REPORT_CSI_16_T → const GhosttySizeReportStyle
-
XTWINOPS cell size in pixels: ESC [ 6 ; height ; width t
const GhosttySizeReportStyle(2) - GHOSTTY_SIZE_REPORT_CSI_18_T → const GhosttySizeReportStyle
-
XTWINOPS text area size in characters: ESC [ 8 ; rows ; cols t
const GhosttySizeReportStyle(3)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → GhosttySizeReportStyle
Constants
-
values
→ const List<
GhosttySizeReportStyle> - A constant List of the values in this enum, in order of their declaration.