GhosttyTerminalColorSchemeFn typedef
Callback function type for color scheme queries (CSI ? 996 n).
Called when the terminal receives a color scheme device status report query. Return true and fill *out_scheme with the current color scheme, or return false to silently ignore the query.
@param terminal The terminal handle
@param userdata The userdata pointer set via GHOSTTY_TERMINAL_OPT_USERDATA
@paramout out_scheme Pointer to store the current color scheme
@return true if the color scheme was filled, false to ignore the query
@ingroup terminal
Implementation
typedef GhosttyTerminalColorSchemeFn =
ffi.Pointer<ffi.NativeFunction<GhosttyTerminalColorSchemeFnFunction>>;