GhosttyTerminalOptions class final
Terminal initialization options.
@ingroup terminal
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - cols ↔ int
-
Terminal width in cells. Must be greater than zero.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- max_scrollback ↔ int
-
Maximum number of lines to keep in scrollback history.
getter/setter pair
- rows ↔ int
-
Terminal height in cells. Must be greater than zero.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited