GhosttyTerminalSelectLineOptions class final
Options for deriving a line selection from a terminal grid reference.
This is a sized struct. Use GHOSTTY_INIT_SIZED() to initialize it. If whitespace is NULL and whitespace_len is 0, Ghostty's default line-trim whitespace codepoints are used. If whitespace_len is non-zero, whitespace must not be NULL.
@ingroup selection
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- ref ↔ GhosttyGridRef
-
Grid reference under which to derive the line selection.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semantic_prompt_boundary ↔ bool
-
Whether semantic prompt state changes should bound the line selection.
getter/setter pair
- size ↔ int
-
Size of this struct in bytes. Must be set to sizeof(GhosttyTerminalSelectLineOptions).
getter/setter pair
-
whitespace
↔ Pointer<
Uint32> -
Optional codepoints to trim from the start and end of the line.
getter/setter pair
- whitespace_len ↔ int
-
Number of entries in whitespace.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited