GhosttyTerminalSelectWordBetweenOptions class final
Options for deriving the nearest word selection between two grid references.
This is a sized struct. Use GHOSTTY_INIT_SIZED() to initialize it. If boundary_codepoints is NULL and boundary_codepoints_len is 0, Ghostty's default word-boundary codepoints are used. If boundary_codepoints_len is non-zero, boundary_codepoints must not be NULL.
@ingroup selection
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
boundary_codepoints
↔ Pointer<
Uint32> -
Optional word-boundary codepoints as uint32_t scalar values.
getter/setter pair
- boundary_codepoints_len ↔ int
-
Number of entries in boundary_codepoints.
getter/setter pair
- end ↔ GhosttyGridRef
-
Ending grid reference for the inclusive search range.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size ↔ int
-
Size of this struct in bytes. Must be set to sizeof(GhosttyTerminalSelectWordBetweenOptions).
getter/setter pair
- start ↔ GhosttyGridRef
-
Starting grid reference for the inclusive search range.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited