GhosttyTerminalTitleChangedFn typedef
Callback function type for title_changed.
Called when the terminal title changes via escape sequences (e.g. OSC 0 or OSC 2). The new title can be queried from the terminal after the callback returns.
@param terminal The terminal handle @param userdata The userdata pointer set via GHOSTTY_TERMINAL_OPT_USERDATA
@ingroup terminal
Implementation
typedef GhosttyTerminalTitleChangedFn =
ffi.Pointer<ffi.NativeFunction<GhosttyTerminalTitleChangedFnFunction>>;