GhosttyTerminalWritePtyFn typedef

Callback function type for write_pty.

Called when the terminal needs to write data back to the pty, for example in response to a device status report or mode query. The data is only valid for the duration of the call; callers must copy it if it needs to persist.

@param terminal The terminal handle @param userdata The userdata pointer set via GHOSTTY_TERMINAL_OPT_USERDATA @param data Pointer to the response bytes @param len Length of the response in bytes

@ingroup terminal

Implementation

typedef GhosttyTerminalWritePtyFn =
    ffi.Pointer<ffi.NativeFunction<GhosttyTerminalWritePtyFnFunction>>;