ghostty_key_event_get_utf8 function
Get the UTF-8 text generated by the key event.
The returned pointer is valid until the event is freed or the UTF-8 text is modified.
@param event The key event handle, must not be NULL @param len Pointer to store the length of the UTF-8 text in bytes (may be NULL) @return The UTF-8 text (or NULL for empty)
@ingroup key
Implementation
@ffi.Native<
ffi.Pointer<ffi.Char> Function(GhosttyKeyEvent, ffi.Pointer<ffi.Size>)
>()
external ffi.Pointer<ffi.Char> ghostty_key_event_get_utf8(
GhosttyKeyEvent event,
ffi.Pointer<ffi.Size> len,
);