ghostty_key_event_set_composing function
- @Native<Void Function(GhosttyKeyEvent, Bool)>(GhosttyKeyEvent, ffi.Bool)>()
- GhosttyKeyEvent event,
- bool composing
Set whether the key event is part of a composition sequence.
@param event The key event handle, must not be NULL @param composing Whether the key event is part of a composition sequence
@ingroup key
Implementation
@ffi.Native<ffi.Void Function(GhosttyKeyEvent, ffi.Bool)>()
external void ghostty_key_event_set_composing(
GhosttyKeyEvent event,
bool composing,
);