ghostty_mouse_encoder_setopt_from_terminal function
- @Native<Void Function(GhosttyMouseEncoder, GhosttyTerminal)>(GhosttyMouseEncoder, GhosttyTerminal)>()
- GhosttyMouseEncoder encoder,
- GhosttyTerminal terminal
Set encoder options from a terminal's current state.
This sets tracking mode and output format from terminal state. It does not modify size or any-button state.
@param encoder The encoder handle, must not be NULL @param terminal The terminal handle, must not be NULL
@ingroup mouse
Implementation
@ffi.Native<ffi.Void Function(GhosttyMouseEncoder, GhosttyTerminal)>()
external void ghostty_mouse_encoder_setopt_from_terminal(
GhosttyMouseEncoder encoder,
GhosttyTerminal terminal,
);