ghostty_mouse_event_get_button function
- @Native<Bool Function(GhosttyMouseEvent, Pointer<
UnsignedInt> )>(GhosttyMouseEvent, ffi.Pointer<ffi.UnsignedInt>)>()
- GhosttyMouseEvent event,
- Pointer<
UnsignedInt> out_button
Get the event button.
@param event The event handle, must not be NULL @param out_button Output pointer for the button value (may be NULL) @return true if a button is set, false if no button is set
@ingroup mouse
Implementation
@ffi.Native<
ffi.Bool Function(GhosttyMouseEvent, ffi.Pointer<ffi.UnsignedInt>)
>()
external bool ghostty_mouse_event_get_button(
GhosttyMouseEvent event,
ffi.Pointer<ffi.UnsignedInt> out_button,
);