ghostty_render_state_free function
- @Native<Void Function(GhosttyRenderState)>(GhosttyRenderState)>()
- GhosttyRenderState state
Free a render state instance.
Releases all resources associated with the render state. After this call, the render state handle becomes invalid.
@param state The render state handle to free (may be NULL)
@ingroup render
Implementation
@ffi.Native<ffi.Void Function(GhosttyRenderState)>()
external void ghostty_render_state_free(GhosttyRenderState state);