ghostty_render_state_row_cells_next function
- @Native<Bool Function(GhosttyRenderStateRowCells)>(GhosttyRenderStateRowCells)>()
Move a render-state row cells iterator to the next cell.
Returns true if the iterator moved successfully and cell data is available to read at the new position.
@param cells The row cells handle to advance (may be NULL)
@return true if advanced to the next cell, false if cells is
NULL or if the iterator has reached the end
@ingroup render
Implementation
@ffi.Native<ffi.Bool Function(GhosttyRenderStateRowCells)>()
external bool ghostty_render_state_row_cells_next(
GhosttyRenderStateRowCells cells,
);