ghostty_terminal_reset function
- @Native<Void Function(GhosttyTerminal)>(GhosttyTerminal)>()
- GhosttyTerminal terminal
Perform a full reset of the terminal (RIS).
Resets all terminal state back to its initial configuration, including modes, scrollback, scrolling region, and screen contents. The terminal dimensions are preserved.
@param terminal The terminal handle (may be NULL, in which case this is a no-op)
@ingroup terminal
Implementation
@ffi.Native<ffi.Void Function(GhosttyTerminal)>()
external void ghostty_terminal_reset(GhosttyTerminal terminal);